# coding: utf-8

# flake8: noqa

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "36.0.0"

# import apis into sdk package
from kubernetes.client.api.well_known_api import WellKnownApi
from kubernetes.client.api.admissionregistration_api import AdmissionregistrationApi
from kubernetes.client.api.admissionregistration_v1_api import AdmissionregistrationV1Api
from kubernetes.client.api.admissionregistration_v1alpha1_api import AdmissionregistrationV1alpha1Api
from kubernetes.client.api.admissionregistration_v1beta1_api import AdmissionregistrationV1beta1Api
from kubernetes.client.api.apiextensions_api import ApiextensionsApi
from kubernetes.client.api.apiextensions_v1_api import ApiextensionsV1Api
from kubernetes.client.api.apiregistration_api import ApiregistrationApi
from kubernetes.client.api.apiregistration_v1_api import ApiregistrationV1Api
from kubernetes.client.api.apis_api import ApisApi
from kubernetes.client.api.apps_api import AppsApi
from kubernetes.client.api.apps_v1_api import AppsV1Api
from kubernetes.client.api.authentication_api import AuthenticationApi
from kubernetes.client.api.authentication_v1_api import AuthenticationV1Api
from kubernetes.client.api.authorization_api import AuthorizationApi
from kubernetes.client.api.authorization_v1_api import AuthorizationV1Api
from kubernetes.client.api.autoscaling_api import AutoscalingApi
from kubernetes.client.api.autoscaling_v1_api import AutoscalingV1Api
from kubernetes.client.api.autoscaling_v2_api import AutoscalingV2Api
from kubernetes.client.api.batch_api import BatchApi
from kubernetes.client.api.batch_v1_api import BatchV1Api
from kubernetes.client.api.certificates_api import CertificatesApi
from kubernetes.client.api.certificates_v1_api import CertificatesV1Api
from kubernetes.client.api.certificates_v1alpha1_api import CertificatesV1alpha1Api
from kubernetes.client.api.certificates_v1beta1_api import CertificatesV1beta1Api
from kubernetes.client.api.coordination_api import CoordinationApi
from kubernetes.client.api.coordination_v1_api import CoordinationV1Api
from kubernetes.client.api.coordination_v1alpha2_api import CoordinationV1alpha2Api
from kubernetes.client.api.coordination_v1beta1_api import CoordinationV1beta1Api
from kubernetes.client.api.core_api import CoreApi
from kubernetes.client.api.core_v1_api import CoreV1Api
from kubernetes.client.api.custom_objects_api import CustomObjectsApi
from kubernetes.client.api.discovery_api import DiscoveryApi
from kubernetes.client.api.discovery_v1_api import DiscoveryV1Api
from kubernetes.client.api.events_api import EventsApi
from kubernetes.client.api.events_v1_api import EventsV1Api
from kubernetes.client.api.flowcontrol_apiserver_api import FlowcontrolApiserverApi
from kubernetes.client.api.flowcontrol_apiserver_v1_api import FlowcontrolApiserverV1Api
from kubernetes.client.api.internal_apiserver_api import InternalApiserverApi
from kubernetes.client.api.internal_apiserver_v1alpha1_api import InternalApiserverV1alpha1Api
from kubernetes.client.api.logs_api import LogsApi
from kubernetes.client.api.networking_api import NetworkingApi
from kubernetes.client.api.networking_v1_api import NetworkingV1Api
from kubernetes.client.api.networking_v1beta1_api import NetworkingV1beta1Api
from kubernetes.client.api.node_api import NodeApi
from kubernetes.client.api.node_v1_api import NodeV1Api
from kubernetes.client.api.openid_api import OpenidApi
from kubernetes.client.api.policy_api import PolicyApi
from kubernetes.client.api.policy_v1_api import PolicyV1Api
from kubernetes.client.api.rbac_authorization_api import RbacAuthorizationApi
from kubernetes.client.api.rbac_authorization_v1_api import RbacAuthorizationV1Api
from kubernetes.client.api.resource_api import ResourceApi
from kubernetes.client.api.resource_v1_api import ResourceV1Api
from kubernetes.client.api.resource_v1alpha3_api import ResourceV1alpha3Api
from kubernetes.client.api.resource_v1beta1_api import ResourceV1beta1Api
from kubernetes.client.api.resource_v1beta2_api import ResourceV1beta2Api
from kubernetes.client.api.scheduling_api import SchedulingApi
from kubernetes.client.api.scheduling_v1_api import SchedulingV1Api
from kubernetes.client.api.scheduling_v1alpha2_api import SchedulingV1alpha2Api
from kubernetes.client.api.storage_api import StorageApi
from kubernetes.client.api.storage_v1_api import StorageV1Api
from kubernetes.client.api.storage_v1beta1_api import StorageV1beta1Api
from kubernetes.client.api.storagemigration_api import StoragemigrationApi
from kubernetes.client.api.storagemigration_v1beta1_api import StoragemigrationV1beta1Api
from kubernetes.client.api.version_api import VersionApi

# import ApiClient
from kubernetes.client.api_client import ApiClient
from kubernetes.client.configuration import Configuration
from kubernetes.client.exceptions import OpenApiException
from kubernetes.client.exceptions import ApiTypeError
from kubernetes.client.exceptions import ApiValueError
from kubernetes.client.exceptions import ApiKeyError
from kubernetes.client.exceptions import ApiAttributeError
from kubernetes.client.exceptions import ApiException
# import models into sdk package
from kubernetes.client.models.admissionregistration_v1_service_reference import AdmissionregistrationV1ServiceReference
from kubernetes.client.models.admissionregistration_v1_webhook_client_config import AdmissionregistrationV1WebhookClientConfig
from kubernetes.client.models.apiextensions_v1_service_reference import ApiextensionsV1ServiceReference
from kubernetes.client.models.apiextensions_v1_webhook_client_config import ApiextensionsV1WebhookClientConfig
from kubernetes.client.models.apiregistration_v1_service_reference import ApiregistrationV1ServiceReference
from kubernetes.client.models.authentication_v1_token_request import AuthenticationV1TokenRequest
from kubernetes.client.models.core_v1_endpoint_port import CoreV1EndpointPort
from kubernetes.client.models.core_v1_event import CoreV1Event
from kubernetes.client.models.core_v1_event_list import CoreV1EventList
from kubernetes.client.models.core_v1_event_series import CoreV1EventSeries
from kubernetes.client.models.core_v1_resource_claim import CoreV1ResourceClaim
from kubernetes.client.models.discovery_v1_endpoint_port import DiscoveryV1EndpointPort
from kubernetes.client.models.events_v1_event import EventsV1Event
from kubernetes.client.models.events_v1_event_list import EventsV1EventList
from kubernetes.client.models.events_v1_event_series import EventsV1EventSeries
from kubernetes.client.models.flowcontrol_v1_subject import FlowcontrolV1Subject
from kubernetes.client.models.rbac_v1_subject import RbacV1Subject
from kubernetes.client.models.resource_v1_resource_claim import ResourceV1ResourceClaim
from kubernetes.client.models.storage_v1_token_request import StorageV1TokenRequest
from kubernetes.client.models.v1_api_group import V1APIGroup
from kubernetes.client.models.v1_api_group_list import V1APIGroupList
from kubernetes.client.models.v1_api_resource import V1APIResource
from kubernetes.client.models.v1_api_resource_list import V1APIResourceList
from kubernetes.client.models.v1_api_service import V1APIService
from kubernetes.client.models.v1_api_service_condition import V1APIServiceCondition
from kubernetes.client.models.v1_api_service_list import V1APIServiceList
from kubernetes.client.models.v1_api_service_spec import V1APIServiceSpec
from kubernetes.client.models.v1_api_service_status import V1APIServiceStatus
from kubernetes.client.models.v1_api_versions import V1APIVersions
from kubernetes.client.models.v1_aws_elastic_block_store_volume_source import V1AWSElasticBlockStoreVolumeSource
from kubernetes.client.models.v1_affinity import V1Affinity
from kubernetes.client.models.v1_aggregation_rule import V1AggregationRule
from kubernetes.client.models.v1_allocated_device_status import V1AllocatedDeviceStatus
from kubernetes.client.models.v1_allocation_result import V1AllocationResult
from kubernetes.client.models.v1_app_armor_profile import V1AppArmorProfile
from kubernetes.client.models.v1_apply_configuration import V1ApplyConfiguration
from kubernetes.client.models.v1_attached_volume import V1AttachedVolume
from kubernetes.client.models.v1_audit_annotation import V1AuditAnnotation
from kubernetes.client.models.v1_azure_disk_volume_source import V1AzureDiskVolumeSource
from kubernetes.client.models.v1_azure_file_persistent_volume_source import V1AzureFilePersistentVolumeSource
from kubernetes.client.models.v1_azure_file_volume_source import V1AzureFileVolumeSource
from kubernetes.client.models.v1_binding import V1Binding
from kubernetes.client.models.v1_bound_object_reference import V1BoundObjectReference
from kubernetes.client.models.v1_cel_device_selector import V1CELDeviceSelector
from kubernetes.client.models.v1_csi_driver import V1CSIDriver
from kubernetes.client.models.v1_csi_driver_list import V1CSIDriverList
from kubernetes.client.models.v1_csi_driver_spec import V1CSIDriverSpec
from kubernetes.client.models.v1_csi_node import V1CSINode
from kubernetes.client.models.v1_csi_node_driver import V1CSINodeDriver
from kubernetes.client.models.v1_csi_node_list import V1CSINodeList
from kubernetes.client.models.v1_csi_node_spec import V1CSINodeSpec
from kubernetes.client.models.v1_csi_persistent_volume_source import V1CSIPersistentVolumeSource
from kubernetes.client.models.v1_csi_storage_capacity import V1CSIStorageCapacity
from kubernetes.client.models.v1_csi_storage_capacity_list import V1CSIStorageCapacityList
from kubernetes.client.models.v1_csi_volume_source import V1CSIVolumeSource
from kubernetes.client.models.v1_capabilities import V1Capabilities
from kubernetes.client.models.v1_capacity_request_policy import V1CapacityRequestPolicy
from kubernetes.client.models.v1_capacity_request_policy_range import V1CapacityRequestPolicyRange
from kubernetes.client.models.v1_capacity_requirements import V1CapacityRequirements
from kubernetes.client.models.v1_ceph_fs_persistent_volume_source import V1CephFSPersistentVolumeSource
from kubernetes.client.models.v1_ceph_fs_volume_source import V1CephFSVolumeSource
from kubernetes.client.models.v1_certificate_signing_request import V1CertificateSigningRequest
from kubernetes.client.models.v1_certificate_signing_request_condition import V1CertificateSigningRequestCondition
from kubernetes.client.models.v1_certificate_signing_request_list import V1CertificateSigningRequestList
from kubernetes.client.models.v1_certificate_signing_request_spec import V1CertificateSigningRequestSpec
from kubernetes.client.models.v1_certificate_signing_request_status import V1CertificateSigningRequestStatus
from kubernetes.client.models.v1_cinder_persistent_volume_source import V1CinderPersistentVolumeSource
from kubernetes.client.models.v1_cinder_volume_source import V1CinderVolumeSource
from kubernetes.client.models.v1_client_ip_config import V1ClientIPConfig
from kubernetes.client.models.v1_cluster_role import V1ClusterRole
from kubernetes.client.models.v1_cluster_role_binding import V1ClusterRoleBinding
from kubernetes.client.models.v1_cluster_role_binding_list import V1ClusterRoleBindingList
from kubernetes.client.models.v1_cluster_role_list import V1ClusterRoleList
from kubernetes.client.models.v1_cluster_trust_bundle_projection import V1ClusterTrustBundleProjection
from kubernetes.client.models.v1_component_condition import V1ComponentCondition
from kubernetes.client.models.v1_component_status import V1ComponentStatus
from kubernetes.client.models.v1_component_status_list import V1ComponentStatusList
from kubernetes.client.models.v1_condition import V1Condition
from kubernetes.client.models.v1_config_map import V1ConfigMap
from kubernetes.client.models.v1_config_map_env_source import V1ConfigMapEnvSource
from kubernetes.client.models.v1_config_map_key_selector import V1ConfigMapKeySelector
from kubernetes.client.models.v1_config_map_list import V1ConfigMapList
from kubernetes.client.models.v1_config_map_node_config_source import V1ConfigMapNodeConfigSource
from kubernetes.client.models.v1_config_map_projection import V1ConfigMapProjection
from kubernetes.client.models.v1_config_map_volume_source import V1ConfigMapVolumeSource
from kubernetes.client.models.v1_container import V1Container
from kubernetes.client.models.v1_container_extended_resource_request import V1ContainerExtendedResourceRequest
from kubernetes.client.models.v1_container_image import V1ContainerImage
from kubernetes.client.models.v1_container_port import V1ContainerPort
from kubernetes.client.models.v1_container_resize_policy import V1ContainerResizePolicy
from kubernetes.client.models.v1_container_restart_rule import V1ContainerRestartRule
from kubernetes.client.models.v1_container_restart_rule_on_exit_codes import V1ContainerRestartRuleOnExitCodes
from kubernetes.client.models.v1_container_state import V1ContainerState
from kubernetes.client.models.v1_container_state_running import V1ContainerStateRunning
from kubernetes.client.models.v1_container_state_terminated import V1ContainerStateTerminated
from kubernetes.client.models.v1_container_state_waiting import V1ContainerStateWaiting
from kubernetes.client.models.v1_container_status import V1ContainerStatus
from kubernetes.client.models.v1_container_user import V1ContainerUser
from kubernetes.client.models.v1_controller_revision import V1ControllerRevision
from kubernetes.client.models.v1_controller_revision_list import V1ControllerRevisionList
from kubernetes.client.models.v1_counter import V1Counter
from kubernetes.client.models.v1_counter_set import V1CounterSet
from kubernetes.client.models.v1_cron_job import V1CronJob
from kubernetes.client.models.v1_cron_job_list import V1CronJobList
from kubernetes.client.models.v1_cron_job_spec import V1CronJobSpec
from kubernetes.client.models.v1_cron_job_status import V1CronJobStatus
from kubernetes.client.models.v1_cross_version_object_reference import V1CrossVersionObjectReference
from kubernetes.client.models.v1_custom_resource_column_definition import V1CustomResourceColumnDefinition
from kubernetes.client.models.v1_custom_resource_conversion import V1CustomResourceConversion
from kubernetes.client.models.v1_custom_resource_definition import V1CustomResourceDefinition
from kubernetes.client.models.v1_custom_resource_definition_condition import V1CustomResourceDefinitionCondition
from kubernetes.client.models.v1_custom_resource_definition_list import V1CustomResourceDefinitionList
from kubernetes.client.models.v1_custom_resource_definition_names import V1CustomResourceDefinitionNames
from kubernetes.client.models.v1_custom_resource_definition_spec import V1CustomResourceDefinitionSpec
from kubernetes.client.models.v1_custom_resource_definition_status import V1CustomResourceDefinitionStatus
from kubernetes.client.models.v1_custom_resource_definition_version import V1CustomResourceDefinitionVersion
from kubernetes.client.models.v1_custom_resource_subresource_scale import V1CustomResourceSubresourceScale
from kubernetes.client.models.v1_custom_resource_subresources import V1CustomResourceSubresources
from kubernetes.client.models.v1_custom_resource_validation import V1CustomResourceValidation
from kubernetes.client.models.v1_daemon_endpoint import V1DaemonEndpoint
from kubernetes.client.models.v1_daemon_set import V1DaemonSet
from kubernetes.client.models.v1_daemon_set_condition import V1DaemonSetCondition
from kubernetes.client.models.v1_daemon_set_list import V1DaemonSetList
from kubernetes.client.models.v1_daemon_set_spec import V1DaemonSetSpec
from kubernetes.client.models.v1_daemon_set_status import V1DaemonSetStatus
from kubernetes.client.models.v1_daemon_set_update_strategy import V1DaemonSetUpdateStrategy
from kubernetes.client.models.v1_delete_options import V1DeleteOptions
from kubernetes.client.models.v1_deployment import V1Deployment
from kubernetes.client.models.v1_deployment_condition import V1DeploymentCondition
from kubernetes.client.models.v1_deployment_list import V1DeploymentList
from kubernetes.client.models.v1_deployment_spec import V1DeploymentSpec
from kubernetes.client.models.v1_deployment_status import V1DeploymentStatus
from kubernetes.client.models.v1_deployment_strategy import V1DeploymentStrategy
from kubernetes.client.models.v1_device import V1Device
from kubernetes.client.models.v1_device_allocation_configuration import V1DeviceAllocationConfiguration
from kubernetes.client.models.v1_device_allocation_result import V1DeviceAllocationResult
from kubernetes.client.models.v1_device_attribute import V1DeviceAttribute
from kubernetes.client.models.v1_device_capacity import V1DeviceCapacity
from kubernetes.client.models.v1_device_claim import V1DeviceClaim
from kubernetes.client.models.v1_device_claim_configuration import V1DeviceClaimConfiguration
from kubernetes.client.models.v1_device_class import V1DeviceClass
from kubernetes.client.models.v1_device_class_configuration import V1DeviceClassConfiguration
from kubernetes.client.models.v1_device_class_list import V1DeviceClassList
from kubernetes.client.models.v1_device_class_spec import V1DeviceClassSpec
from kubernetes.client.models.v1_device_constraint import V1DeviceConstraint
from kubernetes.client.models.v1_device_counter_consumption import V1DeviceCounterConsumption
from kubernetes.client.models.v1_device_request import V1DeviceRequest
from kubernetes.client.models.v1_device_request_allocation_result import V1DeviceRequestAllocationResult
from kubernetes.client.models.v1_device_selector import V1DeviceSelector
from kubernetes.client.models.v1_device_sub_request import V1DeviceSubRequest
from kubernetes.client.models.v1_device_taint import V1DeviceTaint
from kubernetes.client.models.v1_device_toleration import V1DeviceToleration
from kubernetes.client.models.v1_downward_api_projection import V1DownwardAPIProjection
from kubernetes.client.models.v1_downward_api_volume_file import V1DownwardAPIVolumeFile
from kubernetes.client.models.v1_downward_api_volume_source import V1DownwardAPIVolumeSource
from kubernetes.client.models.v1_empty_dir_volume_source import V1EmptyDirVolumeSource
from kubernetes.client.models.v1_endpoint import V1Endpoint
from kubernetes.client.models.v1_endpoint_address import V1EndpointAddress
from kubernetes.client.models.v1_endpoint_conditions import V1EndpointConditions
from kubernetes.client.models.v1_endpoint_hints import V1EndpointHints
from kubernetes.client.models.v1_endpoint_slice import V1EndpointSlice
from kubernetes.client.models.v1_endpoint_slice_list import V1EndpointSliceList
from kubernetes.client.models.v1_endpoint_subset import V1EndpointSubset
from kubernetes.client.models.v1_endpoints import V1Endpoints
from kubernetes.client.models.v1_endpoints_list import V1EndpointsList
from kubernetes.client.models.v1_env_from_source import V1EnvFromSource
from kubernetes.client.models.v1_env_var import V1EnvVar
from kubernetes.client.models.v1_env_var_source import V1EnvVarSource
from kubernetes.client.models.v1_ephemeral_container import V1EphemeralContainer
from kubernetes.client.models.v1_ephemeral_volume_source import V1EphemeralVolumeSource
from kubernetes.client.models.v1_event_source import V1EventSource
from kubernetes.client.models.v1_eviction import V1Eviction
from kubernetes.client.models.v1_exact_device_request import V1ExactDeviceRequest
from kubernetes.client.models.v1_exec_action import V1ExecAction
from kubernetes.client.models.v1_exempt_priority_level_configuration import V1ExemptPriorityLevelConfiguration
from kubernetes.client.models.v1_expression_warning import V1ExpressionWarning
from kubernetes.client.models.v1_external_documentation import V1ExternalDocumentation
from kubernetes.client.models.v1_fc_volume_source import V1FCVolumeSource
from kubernetes.client.models.v1_field_selector_attributes import V1FieldSelectorAttributes
from kubernetes.client.models.v1_field_selector_requirement import V1FieldSelectorRequirement
from kubernetes.client.models.v1_file_key_selector import V1FileKeySelector
from kubernetes.client.models.v1_flex_persistent_volume_source import V1FlexPersistentVolumeSource
from kubernetes.client.models.v1_flex_volume_source import V1FlexVolumeSource
from kubernetes.client.models.v1_flocker_volume_source import V1FlockerVolumeSource
from kubernetes.client.models.v1_flow_distinguisher_method import V1FlowDistinguisherMethod
from kubernetes.client.models.v1_flow_schema import V1FlowSchema
from kubernetes.client.models.v1_flow_schema_condition import V1FlowSchemaCondition
from kubernetes.client.models.v1_flow_schema_list import V1FlowSchemaList
from kubernetes.client.models.v1_flow_schema_spec import V1FlowSchemaSpec
from kubernetes.client.models.v1_flow_schema_status import V1FlowSchemaStatus
from kubernetes.client.models.v1_for_node import V1ForNode
from kubernetes.client.models.v1_for_zone import V1ForZone
from kubernetes.client.models.v1_gce_persistent_disk_volume_source import V1GCEPersistentDiskVolumeSource
from kubernetes.client.models.v1_grpc_action import V1GRPCAction
from kubernetes.client.models.v1_git_repo_volume_source import V1GitRepoVolumeSource
from kubernetes.client.models.v1_glusterfs_persistent_volume_source import V1GlusterfsPersistentVolumeSource
from kubernetes.client.models.v1_glusterfs_volume_source import V1GlusterfsVolumeSource
from kubernetes.client.models.v1_group_resource import V1GroupResource
from kubernetes.client.models.v1_group_subject import V1GroupSubject
from kubernetes.client.models.v1_group_version_for_discovery import V1GroupVersionForDiscovery
from kubernetes.client.models.v1_http_get_action import V1HTTPGetAction
from kubernetes.client.models.v1_http_header import V1HTTPHeader
from kubernetes.client.models.v1_http_ingress_path import V1HTTPIngressPath
from kubernetes.client.models.v1_http_ingress_rule_value import V1HTTPIngressRuleValue
from kubernetes.client.models.v1_horizontal_pod_autoscaler import V1HorizontalPodAutoscaler
from kubernetes.client.models.v1_horizontal_pod_autoscaler_list import V1HorizontalPodAutoscalerList
from kubernetes.client.models.v1_horizontal_pod_autoscaler_spec import V1HorizontalPodAutoscalerSpec
from kubernetes.client.models.v1_horizontal_pod_autoscaler_status import V1HorizontalPodAutoscalerStatus
from kubernetes.client.models.v1_host_alias import V1HostAlias
from kubernetes.client.models.v1_host_ip import V1HostIP
from kubernetes.client.models.v1_host_path_volume_source import V1HostPathVolumeSource
from kubernetes.client.models.v1_ip_address import V1IPAddress
from kubernetes.client.models.v1_ip_address_list import V1IPAddressList
from kubernetes.client.models.v1_ip_address_spec import V1IPAddressSpec
from kubernetes.client.models.v1_ip_block import V1IPBlock
from kubernetes.client.models.v1_iscsi_persistent_volume_source import V1ISCSIPersistentVolumeSource
from kubernetes.client.models.v1_iscsi_volume_source import V1ISCSIVolumeSource
from kubernetes.client.models.v1_image_volume_source import V1ImageVolumeSource
from kubernetes.client.models.v1_image_volume_status import V1ImageVolumeStatus
from kubernetes.client.models.v1_ingress import V1Ingress
from kubernetes.client.models.v1_ingress_backend import V1IngressBackend
from kubernetes.client.models.v1_ingress_class import V1IngressClass
from kubernetes.client.models.v1_ingress_class_list import V1IngressClassList
from kubernetes.client.models.v1_ingress_class_parameters_reference import V1IngressClassParametersReference
from kubernetes.client.models.v1_ingress_class_spec import V1IngressClassSpec
from kubernetes.client.models.v1_ingress_list import V1IngressList
from kubernetes.client.models.v1_ingress_load_balancer_ingress import V1IngressLoadBalancerIngress
from kubernetes.client.models.v1_ingress_load_balancer_status import V1IngressLoadBalancerStatus
from kubernetes.client.models.v1_ingress_port_status import V1IngressPortStatus
from kubernetes.client.models.v1_ingress_rule import V1IngressRule
from kubernetes.client.models.v1_ingress_service_backend import V1IngressServiceBackend
from kubernetes.client.models.v1_ingress_spec import V1IngressSpec
from kubernetes.client.models.v1_ingress_status import V1IngressStatus
from kubernetes.client.models.v1_ingress_tls import V1IngressTLS
from kubernetes.client.models.v1_json_patch import V1JSONPatch
from kubernetes.client.models.v1_json_schema_props import V1JSONSchemaProps
from kubernetes.client.models.v1_job import V1Job
from kubernetes.client.models.v1_job_condition import V1JobCondition
from kubernetes.client.models.v1_job_list import V1JobList
from kubernetes.client.models.v1_job_spec import V1JobSpec
from kubernetes.client.models.v1_job_status import V1JobStatus
from kubernetes.client.models.v1_job_template_spec import V1JobTemplateSpec
from kubernetes.client.models.v1_key_to_path import V1KeyToPath
from kubernetes.client.models.v1_label_selector import V1LabelSelector
from kubernetes.client.models.v1_label_selector_attributes import V1LabelSelectorAttributes
from kubernetes.client.models.v1_label_selector_requirement import V1LabelSelectorRequirement
from kubernetes.client.models.v1_lease import V1Lease
from kubernetes.client.models.v1_lease_list import V1LeaseList
from kubernetes.client.models.v1_lease_spec import V1LeaseSpec
from kubernetes.client.models.v1_lifecycle import V1Lifecycle
from kubernetes.client.models.v1_lifecycle_handler import V1LifecycleHandler
from kubernetes.client.models.v1_limit_range import V1LimitRange
from kubernetes.client.models.v1_limit_range_item import V1LimitRangeItem
from kubernetes.client.models.v1_limit_range_list import V1LimitRangeList
from kubernetes.client.models.v1_limit_range_spec import V1LimitRangeSpec
from kubernetes.client.models.v1_limit_response import V1LimitResponse
from kubernetes.client.models.v1_limited_priority_level_configuration import V1LimitedPriorityLevelConfiguration
from kubernetes.client.models.v1_linux_container_user import V1LinuxContainerUser
from kubernetes.client.models.v1_list_meta import V1ListMeta
from kubernetes.client.models.v1_load_balancer_ingress import V1LoadBalancerIngress
from kubernetes.client.models.v1_load_balancer_status import V1LoadBalancerStatus
from kubernetes.client.models.v1_local_object_reference import V1LocalObjectReference
from kubernetes.client.models.v1_local_subject_access_review import V1LocalSubjectAccessReview
from kubernetes.client.models.v1_local_volume_source import V1LocalVolumeSource
from kubernetes.client.models.v1_managed_fields_entry import V1ManagedFieldsEntry
from kubernetes.client.models.v1_match_condition import V1MatchCondition
from kubernetes.client.models.v1_match_resources import V1MatchResources
from kubernetes.client.models.v1_modify_volume_status import V1ModifyVolumeStatus
from kubernetes.client.models.v1_mutating_admission_policy import V1MutatingAdmissionPolicy
from kubernetes.client.models.v1_mutating_admission_policy_binding import V1MutatingAdmissionPolicyBinding
from kubernetes.client.models.v1_mutating_admission_policy_binding_list import V1MutatingAdmissionPolicyBindingList
from kubernetes.client.models.v1_mutating_admission_policy_binding_spec import V1MutatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1_mutating_admission_policy_list import V1MutatingAdmissionPolicyList
from kubernetes.client.models.v1_mutating_admission_policy_spec import V1MutatingAdmissionPolicySpec
from kubernetes.client.models.v1_mutating_webhook import V1MutatingWebhook
from kubernetes.client.models.v1_mutating_webhook_configuration import V1MutatingWebhookConfiguration
from kubernetes.client.models.v1_mutating_webhook_configuration_list import V1MutatingWebhookConfigurationList
from kubernetes.client.models.v1_mutation import V1Mutation
from kubernetes.client.models.v1_nfs_volume_source import V1NFSVolumeSource
from kubernetes.client.models.v1_named_rule_with_operations import V1NamedRuleWithOperations
from kubernetes.client.models.v1_namespace import V1Namespace
from kubernetes.client.models.v1_namespace_condition import V1NamespaceCondition
from kubernetes.client.models.v1_namespace_list import V1NamespaceList
from kubernetes.client.models.v1_namespace_spec import V1NamespaceSpec
from kubernetes.client.models.v1_namespace_status import V1NamespaceStatus
from kubernetes.client.models.v1_network_device_data import V1NetworkDeviceData
from kubernetes.client.models.v1_network_policy import V1NetworkPolicy
from kubernetes.client.models.v1_network_policy_egress_rule import V1NetworkPolicyEgressRule
from kubernetes.client.models.v1_network_policy_ingress_rule import V1NetworkPolicyIngressRule
from kubernetes.client.models.v1_network_policy_list import V1NetworkPolicyList
from kubernetes.client.models.v1_network_policy_peer import V1NetworkPolicyPeer
from kubernetes.client.models.v1_network_policy_port import V1NetworkPolicyPort
from kubernetes.client.models.v1_network_policy_spec import V1NetworkPolicySpec
from kubernetes.client.models.v1_node import V1Node
from kubernetes.client.models.v1_node_address import V1NodeAddress
from kubernetes.client.models.v1_node_affinity import V1NodeAffinity
from kubernetes.client.models.v1_node_allocatable_resource_claim_status import V1NodeAllocatableResourceClaimStatus
from kubernetes.client.models.v1_node_allocatable_resource_mapping import V1NodeAllocatableResourceMapping
from kubernetes.client.models.v1_node_condition import V1NodeCondition
from kubernetes.client.models.v1_node_config_source import V1NodeConfigSource
from kubernetes.client.models.v1_node_config_status import V1NodeConfigStatus
from kubernetes.client.models.v1_node_daemon_endpoints import V1NodeDaemonEndpoints
from kubernetes.client.models.v1_node_features import V1NodeFeatures
from kubernetes.client.models.v1_node_list import V1NodeList
from kubernetes.client.models.v1_node_runtime_handler import V1NodeRuntimeHandler
from kubernetes.client.models.v1_node_runtime_handler_features import V1NodeRuntimeHandlerFeatures
from kubernetes.client.models.v1_node_selector import V1NodeSelector
from kubernetes.client.models.v1_node_selector_requirement import V1NodeSelectorRequirement
from kubernetes.client.models.v1_node_selector_term import V1NodeSelectorTerm
from kubernetes.client.models.v1_node_spec import V1NodeSpec
from kubernetes.client.models.v1_node_status import V1NodeStatus
from kubernetes.client.models.v1_node_swap_status import V1NodeSwapStatus
from kubernetes.client.models.v1_node_system_info import V1NodeSystemInfo
from kubernetes.client.models.v1_non_resource_attributes import V1NonResourceAttributes
from kubernetes.client.models.v1_non_resource_policy_rule import V1NonResourcePolicyRule
from kubernetes.client.models.v1_non_resource_rule import V1NonResourceRule
from kubernetes.client.models.v1_object_field_selector import V1ObjectFieldSelector
from kubernetes.client.models.v1_object_meta import V1ObjectMeta
from kubernetes.client.models.v1_object_reference import V1ObjectReference
from kubernetes.client.models.v1_opaque_device_configuration import V1OpaqueDeviceConfiguration
from kubernetes.client.models.v1_overhead import V1Overhead
from kubernetes.client.models.v1_owner_reference import V1OwnerReference
from kubernetes.client.models.v1_param_kind import V1ParamKind
from kubernetes.client.models.v1_param_ref import V1ParamRef
from kubernetes.client.models.v1_parent_reference import V1ParentReference
from kubernetes.client.models.v1_persistent_volume import V1PersistentVolume
from kubernetes.client.models.v1_persistent_volume_claim import V1PersistentVolumeClaim
from kubernetes.client.models.v1_persistent_volume_claim_condition import V1PersistentVolumeClaimCondition
from kubernetes.client.models.v1_persistent_volume_claim_list import V1PersistentVolumeClaimList
from kubernetes.client.models.v1_persistent_volume_claim_spec import V1PersistentVolumeClaimSpec
from kubernetes.client.models.v1_persistent_volume_claim_status import V1PersistentVolumeClaimStatus
from kubernetes.client.models.v1_persistent_volume_claim_template import V1PersistentVolumeClaimTemplate
from kubernetes.client.models.v1_persistent_volume_claim_volume_source import V1PersistentVolumeClaimVolumeSource
from kubernetes.client.models.v1_persistent_volume_list import V1PersistentVolumeList
from kubernetes.client.models.v1_persistent_volume_spec import V1PersistentVolumeSpec
from kubernetes.client.models.v1_persistent_volume_status import V1PersistentVolumeStatus
from kubernetes.client.models.v1_photon_persistent_disk_volume_source import V1PhotonPersistentDiskVolumeSource
from kubernetes.client.models.v1_pod import V1Pod
from kubernetes.client.models.v1_pod_affinity import V1PodAffinity
from kubernetes.client.models.v1_pod_affinity_term import V1PodAffinityTerm
from kubernetes.client.models.v1_pod_anti_affinity import V1PodAntiAffinity
from kubernetes.client.models.v1_pod_certificate_projection import V1PodCertificateProjection
from kubernetes.client.models.v1_pod_condition import V1PodCondition
from kubernetes.client.models.v1_pod_dns_config import V1PodDNSConfig
from kubernetes.client.models.v1_pod_dns_config_option import V1PodDNSConfigOption
from kubernetes.client.models.v1_pod_disruption_budget import V1PodDisruptionBudget
from kubernetes.client.models.v1_pod_disruption_budget_list import V1PodDisruptionBudgetList
from kubernetes.client.models.v1_pod_disruption_budget_spec import V1PodDisruptionBudgetSpec
from kubernetes.client.models.v1_pod_disruption_budget_status import V1PodDisruptionBudgetStatus
from kubernetes.client.models.v1_pod_extended_resource_claim_status import V1PodExtendedResourceClaimStatus
from kubernetes.client.models.v1_pod_failure_policy import V1PodFailurePolicy
from kubernetes.client.models.v1_pod_failure_policy_on_exit_codes_requirement import V1PodFailurePolicyOnExitCodesRequirement
from kubernetes.client.models.v1_pod_failure_policy_on_pod_conditions_pattern import V1PodFailurePolicyOnPodConditionsPattern
from kubernetes.client.models.v1_pod_failure_policy_rule import V1PodFailurePolicyRule
from kubernetes.client.models.v1_pod_ip import V1PodIP
from kubernetes.client.models.v1_pod_list import V1PodList
from kubernetes.client.models.v1_pod_os import V1PodOS
from kubernetes.client.models.v1_pod_readiness_gate import V1PodReadinessGate
from kubernetes.client.models.v1_pod_resource_claim import V1PodResourceClaim
from kubernetes.client.models.v1_pod_resource_claim_status import V1PodResourceClaimStatus
from kubernetes.client.models.v1_pod_scheduling_gate import V1PodSchedulingGate
from kubernetes.client.models.v1_pod_scheduling_group import V1PodSchedulingGroup
from kubernetes.client.models.v1_pod_security_context import V1PodSecurityContext
from kubernetes.client.models.v1_pod_spec import V1PodSpec
from kubernetes.client.models.v1_pod_status import V1PodStatus
from kubernetes.client.models.v1_pod_template import V1PodTemplate
from kubernetes.client.models.v1_pod_template_list import V1PodTemplateList
from kubernetes.client.models.v1_pod_template_spec import V1PodTemplateSpec
from kubernetes.client.models.v1_policy_rule import V1PolicyRule
from kubernetes.client.models.v1_policy_rules_with_subjects import V1PolicyRulesWithSubjects
from kubernetes.client.models.v1_port_status import V1PortStatus
from kubernetes.client.models.v1_portworx_volume_source import V1PortworxVolumeSource
from kubernetes.client.models.v1_preconditions import V1Preconditions
from kubernetes.client.models.v1_preferred_scheduling_term import V1PreferredSchedulingTerm
from kubernetes.client.models.v1_priority_class import V1PriorityClass
from kubernetes.client.models.v1_priority_class_list import V1PriorityClassList
from kubernetes.client.models.v1_priority_level_configuration import V1PriorityLevelConfiguration
from kubernetes.client.models.v1_priority_level_configuration_condition import V1PriorityLevelConfigurationCondition
from kubernetes.client.models.v1_priority_level_configuration_list import V1PriorityLevelConfigurationList
from kubernetes.client.models.v1_priority_level_configuration_reference import V1PriorityLevelConfigurationReference
from kubernetes.client.models.v1_priority_level_configuration_spec import V1PriorityLevelConfigurationSpec
from kubernetes.client.models.v1_priority_level_configuration_status import V1PriorityLevelConfigurationStatus
from kubernetes.client.models.v1_probe import V1Probe
from kubernetes.client.models.v1_projected_volume_source import V1ProjectedVolumeSource
from kubernetes.client.models.v1_queuing_configuration import V1QueuingConfiguration
from kubernetes.client.models.v1_quobyte_volume_source import V1QuobyteVolumeSource
from kubernetes.client.models.v1_rbd_persistent_volume_source import V1RBDPersistentVolumeSource
from kubernetes.client.models.v1_rbd_volume_source import V1RBDVolumeSource
from kubernetes.client.models.v1_replica_set import V1ReplicaSet
from kubernetes.client.models.v1_replica_set_condition import V1ReplicaSetCondition
from kubernetes.client.models.v1_replica_set_list import V1ReplicaSetList
from kubernetes.client.models.v1_replica_set_spec import V1ReplicaSetSpec
from kubernetes.client.models.v1_replica_set_status import V1ReplicaSetStatus
from kubernetes.client.models.v1_replication_controller import V1ReplicationController
from kubernetes.client.models.v1_replication_controller_condition import V1ReplicationControllerCondition
from kubernetes.client.models.v1_replication_controller_list import V1ReplicationControllerList
from kubernetes.client.models.v1_replication_controller_spec import V1ReplicationControllerSpec
from kubernetes.client.models.v1_replication_controller_status import V1ReplicationControllerStatus
from kubernetes.client.models.v1_resource_attributes import V1ResourceAttributes
from kubernetes.client.models.v1_resource_claim_consumer_reference import V1ResourceClaimConsumerReference
from kubernetes.client.models.v1_resource_claim_list import V1ResourceClaimList
from kubernetes.client.models.v1_resource_claim_spec import V1ResourceClaimSpec
from kubernetes.client.models.v1_resource_claim_status import V1ResourceClaimStatus
from kubernetes.client.models.v1_resource_claim_template import V1ResourceClaimTemplate
from kubernetes.client.models.v1_resource_claim_template_list import V1ResourceClaimTemplateList
from kubernetes.client.models.v1_resource_claim_template_spec import V1ResourceClaimTemplateSpec
from kubernetes.client.models.v1_resource_field_selector import V1ResourceFieldSelector
from kubernetes.client.models.v1_resource_health import V1ResourceHealth
from kubernetes.client.models.v1_resource_policy_rule import V1ResourcePolicyRule
from kubernetes.client.models.v1_resource_pool import V1ResourcePool
from kubernetes.client.models.v1_resource_quota import V1ResourceQuota
from kubernetes.client.models.v1_resource_quota_list import V1ResourceQuotaList
from kubernetes.client.models.v1_resource_quota_spec import V1ResourceQuotaSpec
from kubernetes.client.models.v1_resource_quota_status import V1ResourceQuotaStatus
from kubernetes.client.models.v1_resource_requirements import V1ResourceRequirements
from kubernetes.client.models.v1_resource_rule import V1ResourceRule
from kubernetes.client.models.v1_resource_slice import V1ResourceSlice
from kubernetes.client.models.v1_resource_slice_list import V1ResourceSliceList
from kubernetes.client.models.v1_resource_slice_spec import V1ResourceSliceSpec
from kubernetes.client.models.v1_resource_status import V1ResourceStatus
from kubernetes.client.models.v1_role import V1Role
from kubernetes.client.models.v1_role_binding import V1RoleBinding
from kubernetes.client.models.v1_role_binding_list import V1RoleBindingList
from kubernetes.client.models.v1_role_list import V1RoleList
from kubernetes.client.models.v1_role_ref import V1RoleRef
from kubernetes.client.models.v1_rolling_update_daemon_set import V1RollingUpdateDaemonSet
from kubernetes.client.models.v1_rolling_update_deployment import V1RollingUpdateDeployment
from kubernetes.client.models.v1_rolling_update_stateful_set_strategy import V1RollingUpdateStatefulSetStrategy
from kubernetes.client.models.v1_rule_with_operations import V1RuleWithOperations
from kubernetes.client.models.v1_runtime_class import V1RuntimeClass
from kubernetes.client.models.v1_runtime_class_list import V1RuntimeClassList
from kubernetes.client.models.v1_se_linux_options import V1SELinuxOptions
from kubernetes.client.models.v1_scale import V1Scale
from kubernetes.client.models.v1_scale_io_persistent_volume_source import V1ScaleIOPersistentVolumeSource
from kubernetes.client.models.v1_scale_io_volume_source import V1ScaleIOVolumeSource
from kubernetes.client.models.v1_scale_spec import V1ScaleSpec
from kubernetes.client.models.v1_scale_status import V1ScaleStatus
from kubernetes.client.models.v1_scheduling import V1Scheduling
from kubernetes.client.models.v1_scope_selector import V1ScopeSelector
from kubernetes.client.models.v1_scoped_resource_selector_requirement import V1ScopedResourceSelectorRequirement
from kubernetes.client.models.v1_seccomp_profile import V1SeccompProfile
from kubernetes.client.models.v1_secret import V1Secret
from kubernetes.client.models.v1_secret_env_source import V1SecretEnvSource
from kubernetes.client.models.v1_secret_key_selector import V1SecretKeySelector
from kubernetes.client.models.v1_secret_list import V1SecretList
from kubernetes.client.models.v1_secret_projection import V1SecretProjection
from kubernetes.client.models.v1_secret_reference import V1SecretReference
from kubernetes.client.models.v1_secret_volume_source import V1SecretVolumeSource
from kubernetes.client.models.v1_security_context import V1SecurityContext
from kubernetes.client.models.v1_selectable_field import V1SelectableField
from kubernetes.client.models.v1_self_subject_access_review import V1SelfSubjectAccessReview
from kubernetes.client.models.v1_self_subject_access_review_spec import V1SelfSubjectAccessReviewSpec
from kubernetes.client.models.v1_self_subject_review import V1SelfSubjectReview
from kubernetes.client.models.v1_self_subject_review_status import V1SelfSubjectReviewStatus
from kubernetes.client.models.v1_self_subject_rules_review import V1SelfSubjectRulesReview
from kubernetes.client.models.v1_self_subject_rules_review_spec import V1SelfSubjectRulesReviewSpec
from kubernetes.client.models.v1_server_address_by_client_cidr import V1ServerAddressByClientCIDR
from kubernetes.client.models.v1_service import V1Service
from kubernetes.client.models.v1_service_account import V1ServiceAccount
from kubernetes.client.models.v1_service_account_list import V1ServiceAccountList
from kubernetes.client.models.v1_service_account_subject import V1ServiceAccountSubject
from kubernetes.client.models.v1_service_account_token_projection import V1ServiceAccountTokenProjection
from kubernetes.client.models.v1_service_backend_port import V1ServiceBackendPort
from kubernetes.client.models.v1_service_cidr import V1ServiceCIDR
from kubernetes.client.models.v1_service_cidr_list import V1ServiceCIDRList
from kubernetes.client.models.v1_service_cidr_spec import V1ServiceCIDRSpec
from kubernetes.client.models.v1_service_cidr_status import V1ServiceCIDRStatus
from kubernetes.client.models.v1_service_list import V1ServiceList
from kubernetes.client.models.v1_service_port import V1ServicePort
from kubernetes.client.models.v1_service_spec import V1ServiceSpec
from kubernetes.client.models.v1_service_status import V1ServiceStatus
from kubernetes.client.models.v1_session_affinity_config import V1SessionAffinityConfig
from kubernetes.client.models.v1_shard_info import V1ShardInfo
from kubernetes.client.models.v1_sleep_action import V1SleepAction
from kubernetes.client.models.v1_stateful_set import V1StatefulSet
from kubernetes.client.models.v1_stateful_set_condition import V1StatefulSetCondition
from kubernetes.client.models.v1_stateful_set_list import V1StatefulSetList
from kubernetes.client.models.v1_stateful_set_ordinals import V1StatefulSetOrdinals
from kubernetes.client.models.v1_stateful_set_persistent_volume_claim_retention_policy import V1StatefulSetPersistentVolumeClaimRetentionPolicy
from kubernetes.client.models.v1_stateful_set_spec import V1StatefulSetSpec
from kubernetes.client.models.v1_stateful_set_status import V1StatefulSetStatus
from kubernetes.client.models.v1_stateful_set_update_strategy import V1StatefulSetUpdateStrategy
from kubernetes.client.models.v1_status import V1Status
from kubernetes.client.models.v1_status_cause import V1StatusCause
from kubernetes.client.models.v1_status_details import V1StatusDetails
from kubernetes.client.models.v1_storage_class import V1StorageClass
from kubernetes.client.models.v1_storage_class_list import V1StorageClassList
from kubernetes.client.models.v1_storage_os_persistent_volume_source import V1StorageOSPersistentVolumeSource
from kubernetes.client.models.v1_storage_os_volume_source import V1StorageOSVolumeSource
from kubernetes.client.models.v1_subject_access_review import V1SubjectAccessReview
from kubernetes.client.models.v1_subject_access_review_spec import V1SubjectAccessReviewSpec
from kubernetes.client.models.v1_subject_access_review_status import V1SubjectAccessReviewStatus
from kubernetes.client.models.v1_subject_rules_review_status import V1SubjectRulesReviewStatus
from kubernetes.client.models.v1_success_policy import V1SuccessPolicy
from kubernetes.client.models.v1_success_policy_rule import V1SuccessPolicyRule
from kubernetes.client.models.v1_sysctl import V1Sysctl
from kubernetes.client.models.v1_tcp_socket_action import V1TCPSocketAction
from kubernetes.client.models.v1_taint import V1Taint
from kubernetes.client.models.v1_token_request_spec import V1TokenRequestSpec
from kubernetes.client.models.v1_token_request_status import V1TokenRequestStatus
from kubernetes.client.models.v1_token_review import V1TokenReview
from kubernetes.client.models.v1_token_review_spec import V1TokenReviewSpec
from kubernetes.client.models.v1_token_review_status import V1TokenReviewStatus
from kubernetes.client.models.v1_toleration import V1Toleration
from kubernetes.client.models.v1_topology_selector_label_requirement import V1TopologySelectorLabelRequirement
from kubernetes.client.models.v1_topology_selector_term import V1TopologySelectorTerm
from kubernetes.client.models.v1_topology_spread_constraint import V1TopologySpreadConstraint
from kubernetes.client.models.v1_type_checking import V1TypeChecking
from kubernetes.client.models.v1_typed_local_object_reference import V1TypedLocalObjectReference
from kubernetes.client.models.v1_typed_object_reference import V1TypedObjectReference
from kubernetes.client.models.v1_uncounted_terminated_pods import V1UncountedTerminatedPods
from kubernetes.client.models.v1_user_info import V1UserInfo
from kubernetes.client.models.v1_user_subject import V1UserSubject
from kubernetes.client.models.v1_validating_admission_policy import V1ValidatingAdmissionPolicy
from kubernetes.client.models.v1_validating_admission_policy_binding import V1ValidatingAdmissionPolicyBinding
from kubernetes.client.models.v1_validating_admission_policy_binding_list import V1ValidatingAdmissionPolicyBindingList
from kubernetes.client.models.v1_validating_admission_policy_binding_spec import V1ValidatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1_validating_admission_policy_list import V1ValidatingAdmissionPolicyList
from kubernetes.client.models.v1_validating_admission_policy_spec import V1ValidatingAdmissionPolicySpec
from kubernetes.client.models.v1_validating_admission_policy_status import V1ValidatingAdmissionPolicyStatus
from kubernetes.client.models.v1_validating_webhook import V1ValidatingWebhook
from kubernetes.client.models.v1_validating_webhook_configuration import V1ValidatingWebhookConfiguration
from kubernetes.client.models.v1_validating_webhook_configuration_list import V1ValidatingWebhookConfigurationList
from kubernetes.client.models.v1_validation import V1Validation
from kubernetes.client.models.v1_validation_rule import V1ValidationRule
from kubernetes.client.models.v1_variable import V1Variable
from kubernetes.client.models.v1_volume import V1Volume
from kubernetes.client.models.v1_volume_attachment import V1VolumeAttachment
from kubernetes.client.models.v1_volume_attachment_list import V1VolumeAttachmentList
from kubernetes.client.models.v1_volume_attachment_source import V1VolumeAttachmentSource
from kubernetes.client.models.v1_volume_attachment_spec import V1VolumeAttachmentSpec
from kubernetes.client.models.v1_volume_attachment_status import V1VolumeAttachmentStatus
from kubernetes.client.models.v1_volume_attributes_class import V1VolumeAttributesClass
from kubernetes.client.models.v1_volume_attributes_class_list import V1VolumeAttributesClassList
from kubernetes.client.models.v1_volume_device import V1VolumeDevice
from kubernetes.client.models.v1_volume_error import V1VolumeError
from kubernetes.client.models.v1_volume_mount import V1VolumeMount
from kubernetes.client.models.v1_volume_mount_status import V1VolumeMountStatus
from kubernetes.client.models.v1_volume_node_affinity import V1VolumeNodeAffinity
from kubernetes.client.models.v1_volume_node_resources import V1VolumeNodeResources
from kubernetes.client.models.v1_volume_projection import V1VolumeProjection
from kubernetes.client.models.v1_volume_resource_requirements import V1VolumeResourceRequirements
from kubernetes.client.models.v1_volume_status import V1VolumeStatus
from kubernetes.client.models.v1_vsphere_virtual_disk_volume_source import V1VsphereVirtualDiskVolumeSource
from kubernetes.client.models.v1_watch_event import V1WatchEvent
from kubernetes.client.models.v1_webhook_conversion import V1WebhookConversion
from kubernetes.client.models.v1_weighted_pod_affinity_term import V1WeightedPodAffinityTerm
from kubernetes.client.models.v1_windows_security_context_options import V1WindowsSecurityContextOptions
from kubernetes.client.models.v1alpha1_apply_configuration import V1alpha1ApplyConfiguration
from kubernetes.client.models.v1alpha1_cluster_trust_bundle import V1alpha1ClusterTrustBundle
from kubernetes.client.models.v1alpha1_cluster_trust_bundle_list import V1alpha1ClusterTrustBundleList
from kubernetes.client.models.v1alpha1_cluster_trust_bundle_spec import V1alpha1ClusterTrustBundleSpec
from kubernetes.client.models.v1alpha1_json_patch import V1alpha1JSONPatch
from kubernetes.client.models.v1alpha1_match_condition import V1alpha1MatchCondition
from kubernetes.client.models.v1alpha1_match_resources import V1alpha1MatchResources
from kubernetes.client.models.v1alpha1_mutating_admission_policy import V1alpha1MutatingAdmissionPolicy
from kubernetes.client.models.v1alpha1_mutating_admission_policy_binding import V1alpha1MutatingAdmissionPolicyBinding
from kubernetes.client.models.v1alpha1_mutating_admission_policy_binding_list import V1alpha1MutatingAdmissionPolicyBindingList
from kubernetes.client.models.v1alpha1_mutating_admission_policy_binding_spec import V1alpha1MutatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1alpha1_mutating_admission_policy_list import V1alpha1MutatingAdmissionPolicyList
from kubernetes.client.models.v1alpha1_mutating_admission_policy_spec import V1alpha1MutatingAdmissionPolicySpec
from kubernetes.client.models.v1alpha1_mutation import V1alpha1Mutation
from kubernetes.client.models.v1alpha1_named_rule_with_operations import V1alpha1NamedRuleWithOperations
from kubernetes.client.models.v1alpha1_param_kind import V1alpha1ParamKind
from kubernetes.client.models.v1alpha1_param_ref import V1alpha1ParamRef
from kubernetes.client.models.v1alpha1_server_storage_version import V1alpha1ServerStorageVersion
from kubernetes.client.models.v1alpha1_storage_version import V1alpha1StorageVersion
from kubernetes.client.models.v1alpha1_storage_version_condition import V1alpha1StorageVersionCondition
from kubernetes.client.models.v1alpha1_storage_version_list import V1alpha1StorageVersionList
from kubernetes.client.models.v1alpha1_storage_version_status import V1alpha1StorageVersionStatus
from kubernetes.client.models.v1alpha1_variable import V1alpha1Variable
from kubernetes.client.models.v1alpha2_gang_scheduling_policy import V1alpha2GangSchedulingPolicy
from kubernetes.client.models.v1alpha2_lease_candidate import V1alpha2LeaseCandidate
from kubernetes.client.models.v1alpha2_lease_candidate_list import V1alpha2LeaseCandidateList
from kubernetes.client.models.v1alpha2_lease_candidate_spec import V1alpha2LeaseCandidateSpec
from kubernetes.client.models.v1alpha2_pod_group import V1alpha2PodGroup
from kubernetes.client.models.v1alpha2_pod_group_list import V1alpha2PodGroupList
from kubernetes.client.models.v1alpha2_pod_group_resource_claim import V1alpha2PodGroupResourceClaim
from kubernetes.client.models.v1alpha2_pod_group_resource_claim_status import V1alpha2PodGroupResourceClaimStatus
from kubernetes.client.models.v1alpha2_pod_group_scheduling_constraints import V1alpha2PodGroupSchedulingConstraints
from kubernetes.client.models.v1alpha2_pod_group_scheduling_policy import V1alpha2PodGroupSchedulingPolicy
from kubernetes.client.models.v1alpha2_pod_group_spec import V1alpha2PodGroupSpec
from kubernetes.client.models.v1alpha2_pod_group_status import V1alpha2PodGroupStatus
from kubernetes.client.models.v1alpha2_pod_group_template import V1alpha2PodGroupTemplate
from kubernetes.client.models.v1alpha2_pod_group_template_reference import V1alpha2PodGroupTemplateReference
from kubernetes.client.models.v1alpha2_topology_constraint import V1alpha2TopologyConstraint
from kubernetes.client.models.v1alpha2_typed_local_object_reference import V1alpha2TypedLocalObjectReference
from kubernetes.client.models.v1alpha2_workload import V1alpha2Workload
from kubernetes.client.models.v1alpha2_workload_list import V1alpha2WorkloadList
from kubernetes.client.models.v1alpha2_workload_pod_group_template_reference import V1alpha2WorkloadPodGroupTemplateReference
from kubernetes.client.models.v1alpha2_workload_spec import V1alpha2WorkloadSpec
from kubernetes.client.models.v1alpha3_device_taint import V1alpha3DeviceTaint
from kubernetes.client.models.v1alpha3_device_taint_rule import V1alpha3DeviceTaintRule
from kubernetes.client.models.v1alpha3_device_taint_rule_list import V1alpha3DeviceTaintRuleList
from kubernetes.client.models.v1alpha3_device_taint_rule_spec import V1alpha3DeviceTaintRuleSpec
from kubernetes.client.models.v1alpha3_device_taint_rule_status import V1alpha3DeviceTaintRuleStatus
from kubernetes.client.models.v1alpha3_device_taint_selector import V1alpha3DeviceTaintSelector
from kubernetes.client.models.v1alpha3_pool_status import V1alpha3PoolStatus
from kubernetes.client.models.v1alpha3_resource_pool_status_request import V1alpha3ResourcePoolStatusRequest
from kubernetes.client.models.v1alpha3_resource_pool_status_request_list import V1alpha3ResourcePoolStatusRequestList
from kubernetes.client.models.v1alpha3_resource_pool_status_request_spec import V1alpha3ResourcePoolStatusRequestSpec
from kubernetes.client.models.v1alpha3_resource_pool_status_request_status import V1alpha3ResourcePoolStatusRequestStatus
from kubernetes.client.models.v1beta1_allocated_device_status import V1beta1AllocatedDeviceStatus
from kubernetes.client.models.v1beta1_allocation_result import V1beta1AllocationResult
from kubernetes.client.models.v1beta1_apply_configuration import V1beta1ApplyConfiguration
from kubernetes.client.models.v1beta1_basic_device import V1beta1BasicDevice
from kubernetes.client.models.v1beta1_cel_device_selector import V1beta1CELDeviceSelector
from kubernetes.client.models.v1beta1_capacity_request_policy import V1beta1CapacityRequestPolicy
from kubernetes.client.models.v1beta1_capacity_request_policy_range import V1beta1CapacityRequestPolicyRange
from kubernetes.client.models.v1beta1_capacity_requirements import V1beta1CapacityRequirements
from kubernetes.client.models.v1beta1_cluster_trust_bundle import V1beta1ClusterTrustBundle
from kubernetes.client.models.v1beta1_cluster_trust_bundle_list import V1beta1ClusterTrustBundleList
from kubernetes.client.models.v1beta1_cluster_trust_bundle_spec import V1beta1ClusterTrustBundleSpec
from kubernetes.client.models.v1beta1_counter import V1beta1Counter
from kubernetes.client.models.v1beta1_counter_set import V1beta1CounterSet
from kubernetes.client.models.v1beta1_device import V1beta1Device
from kubernetes.client.models.v1beta1_device_allocation_configuration import V1beta1DeviceAllocationConfiguration
from kubernetes.client.models.v1beta1_device_allocation_result import V1beta1DeviceAllocationResult
from kubernetes.client.models.v1beta1_device_attribute import V1beta1DeviceAttribute
from kubernetes.client.models.v1beta1_device_capacity import V1beta1DeviceCapacity
from kubernetes.client.models.v1beta1_device_claim import V1beta1DeviceClaim
from kubernetes.client.models.v1beta1_device_claim_configuration import V1beta1DeviceClaimConfiguration
from kubernetes.client.models.v1beta1_device_class import V1beta1DeviceClass
from kubernetes.client.models.v1beta1_device_class_configuration import V1beta1DeviceClassConfiguration
from kubernetes.client.models.v1beta1_device_class_list import V1beta1DeviceClassList
from kubernetes.client.models.v1beta1_device_class_spec import V1beta1DeviceClassSpec
from kubernetes.client.models.v1beta1_device_constraint import V1beta1DeviceConstraint
from kubernetes.client.models.v1beta1_device_counter_consumption import V1beta1DeviceCounterConsumption
from kubernetes.client.models.v1beta1_device_request import V1beta1DeviceRequest
from kubernetes.client.models.v1beta1_device_request_allocation_result import V1beta1DeviceRequestAllocationResult
from kubernetes.client.models.v1beta1_device_selector import V1beta1DeviceSelector
from kubernetes.client.models.v1beta1_device_sub_request import V1beta1DeviceSubRequest
from kubernetes.client.models.v1beta1_device_taint import V1beta1DeviceTaint
from kubernetes.client.models.v1beta1_device_toleration import V1beta1DeviceToleration
from kubernetes.client.models.v1beta1_ip_address import V1beta1IPAddress
from kubernetes.client.models.v1beta1_ip_address_list import V1beta1IPAddressList
from kubernetes.client.models.v1beta1_ip_address_spec import V1beta1IPAddressSpec
from kubernetes.client.models.v1beta1_json_patch import V1beta1JSONPatch
from kubernetes.client.models.v1beta1_lease_candidate import V1beta1LeaseCandidate
from kubernetes.client.models.v1beta1_lease_candidate_list import V1beta1LeaseCandidateList
from kubernetes.client.models.v1beta1_lease_candidate_spec import V1beta1LeaseCandidateSpec
from kubernetes.client.models.v1beta1_match_condition import V1beta1MatchCondition
from kubernetes.client.models.v1beta1_match_resources import V1beta1MatchResources
from kubernetes.client.models.v1beta1_mutating_admission_policy import V1beta1MutatingAdmissionPolicy
from kubernetes.client.models.v1beta1_mutating_admission_policy_binding import V1beta1MutatingAdmissionPolicyBinding
from kubernetes.client.models.v1beta1_mutating_admission_policy_binding_list import V1beta1MutatingAdmissionPolicyBindingList
from kubernetes.client.models.v1beta1_mutating_admission_policy_binding_spec import V1beta1MutatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1beta1_mutating_admission_policy_list import V1beta1MutatingAdmissionPolicyList
from kubernetes.client.models.v1beta1_mutating_admission_policy_spec import V1beta1MutatingAdmissionPolicySpec
from kubernetes.client.models.v1beta1_mutation import V1beta1Mutation
from kubernetes.client.models.v1beta1_named_rule_with_operations import V1beta1NamedRuleWithOperations
from kubernetes.client.models.v1beta1_network_device_data import V1beta1NetworkDeviceData
from kubernetes.client.models.v1beta1_node_allocatable_resource_mapping import V1beta1NodeAllocatableResourceMapping
from kubernetes.client.models.v1beta1_opaque_device_configuration import V1beta1OpaqueDeviceConfiguration
from kubernetes.client.models.v1beta1_param_kind import V1beta1ParamKind
from kubernetes.client.models.v1beta1_param_ref import V1beta1ParamRef
from kubernetes.client.models.v1beta1_parent_reference import V1beta1ParentReference
from kubernetes.client.models.v1beta1_pod_certificate_request import V1beta1PodCertificateRequest
from kubernetes.client.models.v1beta1_pod_certificate_request_list import V1beta1PodCertificateRequestList
from kubernetes.client.models.v1beta1_pod_certificate_request_spec import V1beta1PodCertificateRequestSpec
from kubernetes.client.models.v1beta1_pod_certificate_request_status import V1beta1PodCertificateRequestStatus
from kubernetes.client.models.v1beta1_resource_claim import V1beta1ResourceClaim
from kubernetes.client.models.v1beta1_resource_claim_consumer_reference import V1beta1ResourceClaimConsumerReference
from kubernetes.client.models.v1beta1_resource_claim_list import V1beta1ResourceClaimList
from kubernetes.client.models.v1beta1_resource_claim_spec import V1beta1ResourceClaimSpec
from kubernetes.client.models.v1beta1_resource_claim_status import V1beta1ResourceClaimStatus
from kubernetes.client.models.v1beta1_resource_claim_template import V1beta1ResourceClaimTemplate
from kubernetes.client.models.v1beta1_resource_claim_template_list import V1beta1ResourceClaimTemplateList
from kubernetes.client.models.v1beta1_resource_claim_template_spec import V1beta1ResourceClaimTemplateSpec
from kubernetes.client.models.v1beta1_resource_pool import V1beta1ResourcePool
from kubernetes.client.models.v1beta1_resource_slice import V1beta1ResourceSlice
from kubernetes.client.models.v1beta1_resource_slice_list import V1beta1ResourceSliceList
from kubernetes.client.models.v1beta1_resource_slice_spec import V1beta1ResourceSliceSpec
from kubernetes.client.models.v1beta1_service_cidr import V1beta1ServiceCIDR
from kubernetes.client.models.v1beta1_service_cidr_list import V1beta1ServiceCIDRList
from kubernetes.client.models.v1beta1_service_cidr_spec import V1beta1ServiceCIDRSpec
from kubernetes.client.models.v1beta1_service_cidr_status import V1beta1ServiceCIDRStatus
from kubernetes.client.models.v1beta1_storage_version_migration import V1beta1StorageVersionMigration
from kubernetes.client.models.v1beta1_storage_version_migration_list import V1beta1StorageVersionMigrationList
from kubernetes.client.models.v1beta1_storage_version_migration_spec import V1beta1StorageVersionMigrationSpec
from kubernetes.client.models.v1beta1_storage_version_migration_status import V1beta1StorageVersionMigrationStatus
from kubernetes.client.models.v1beta1_variable import V1beta1Variable
from kubernetes.client.models.v1beta1_volume_attributes_class import V1beta1VolumeAttributesClass
from kubernetes.client.models.v1beta1_volume_attributes_class_list import V1beta1VolumeAttributesClassList
from kubernetes.client.models.v1beta2_allocated_device_status import V1beta2AllocatedDeviceStatus
from kubernetes.client.models.v1beta2_allocation_result import V1beta2AllocationResult
from kubernetes.client.models.v1beta2_cel_device_selector import V1beta2CELDeviceSelector
from kubernetes.client.models.v1beta2_capacity_request_policy import V1beta2CapacityRequestPolicy
from kubernetes.client.models.v1beta2_capacity_request_policy_range import V1beta2CapacityRequestPolicyRange
from kubernetes.client.models.v1beta2_capacity_requirements import V1beta2CapacityRequirements
from kubernetes.client.models.v1beta2_counter import V1beta2Counter
from kubernetes.client.models.v1beta2_counter_set import V1beta2CounterSet
from kubernetes.client.models.v1beta2_device import V1beta2Device
from kubernetes.client.models.v1beta2_device_allocation_configuration import V1beta2DeviceAllocationConfiguration
from kubernetes.client.models.v1beta2_device_allocation_result import V1beta2DeviceAllocationResult
from kubernetes.client.models.v1beta2_device_attribute import V1beta2DeviceAttribute
from kubernetes.client.models.v1beta2_device_capacity import V1beta2DeviceCapacity
from kubernetes.client.models.v1beta2_device_claim import V1beta2DeviceClaim
from kubernetes.client.models.v1beta2_device_claim_configuration import V1beta2DeviceClaimConfiguration
from kubernetes.client.models.v1beta2_device_class import V1beta2DeviceClass
from kubernetes.client.models.v1beta2_device_class_configuration import V1beta2DeviceClassConfiguration
from kubernetes.client.models.v1beta2_device_class_list import V1beta2DeviceClassList
from kubernetes.client.models.v1beta2_device_class_spec import V1beta2DeviceClassSpec
from kubernetes.client.models.v1beta2_device_constraint import V1beta2DeviceConstraint
from kubernetes.client.models.v1beta2_device_counter_consumption import V1beta2DeviceCounterConsumption
from kubernetes.client.models.v1beta2_device_request import V1beta2DeviceRequest
from kubernetes.client.models.v1beta2_device_request_allocation_result import V1beta2DeviceRequestAllocationResult
from kubernetes.client.models.v1beta2_device_selector import V1beta2DeviceSelector
from kubernetes.client.models.v1beta2_device_sub_request import V1beta2DeviceSubRequest
from kubernetes.client.models.v1beta2_device_taint import V1beta2DeviceTaint
from kubernetes.client.models.v1beta2_device_taint_rule import V1beta2DeviceTaintRule
from kubernetes.client.models.v1beta2_device_taint_rule_list import V1beta2DeviceTaintRuleList
from kubernetes.client.models.v1beta2_device_taint_rule_spec import V1beta2DeviceTaintRuleSpec
from kubernetes.client.models.v1beta2_device_taint_rule_status import V1beta2DeviceTaintRuleStatus
from kubernetes.client.models.v1beta2_device_taint_selector import V1beta2DeviceTaintSelector
from kubernetes.client.models.v1beta2_device_toleration import V1beta2DeviceToleration
from kubernetes.client.models.v1beta2_exact_device_request import V1beta2ExactDeviceRequest
from kubernetes.client.models.v1beta2_network_device_data import V1beta2NetworkDeviceData
from kubernetes.client.models.v1beta2_node_allocatable_resource_mapping import V1beta2NodeAllocatableResourceMapping
from kubernetes.client.models.v1beta2_opaque_device_configuration import V1beta2OpaqueDeviceConfiguration
from kubernetes.client.models.v1beta2_resource_claim import V1beta2ResourceClaim
from kubernetes.client.models.v1beta2_resource_claim_consumer_reference import V1beta2ResourceClaimConsumerReference
from kubernetes.client.models.v1beta2_resource_claim_list import V1beta2ResourceClaimList
from kubernetes.client.models.v1beta2_resource_claim_spec import V1beta2ResourceClaimSpec
from kubernetes.client.models.v1beta2_resource_claim_status import V1beta2ResourceClaimStatus
from kubernetes.client.models.v1beta2_resource_claim_template import V1beta2ResourceClaimTemplate
from kubernetes.client.models.v1beta2_resource_claim_template_list import V1beta2ResourceClaimTemplateList
from kubernetes.client.models.v1beta2_resource_claim_template_spec import V1beta2ResourceClaimTemplateSpec
from kubernetes.client.models.v1beta2_resource_pool import V1beta2ResourcePool
from kubernetes.client.models.v1beta2_resource_slice import V1beta2ResourceSlice
from kubernetes.client.models.v1beta2_resource_slice_list import V1beta2ResourceSliceList
from kubernetes.client.models.v1beta2_resource_slice_spec import V1beta2ResourceSliceSpec
from kubernetes.client.models.v2_api_group_discovery import V2APIGroupDiscovery
from kubernetes.client.models.v2_api_group_discovery_list import V2APIGroupDiscoveryList
from kubernetes.client.models.v2_api_resource_discovery import V2APIResourceDiscovery
from kubernetes.client.models.v2_api_subresource_discovery import V2APISubresourceDiscovery
from kubernetes.client.models.v2_api_version_discovery import V2APIVersionDiscovery
from kubernetes.client.models.v2_container_resource_metric_source import V2ContainerResourceMetricSource
from kubernetes.client.models.v2_container_resource_metric_status import V2ContainerResourceMetricStatus
from kubernetes.client.models.v2_cross_version_object_reference import V2CrossVersionObjectReference
from kubernetes.client.models.v2_external_metric_source import V2ExternalMetricSource
from kubernetes.client.models.v2_external_metric_status import V2ExternalMetricStatus
from kubernetes.client.models.v2_hpa_scaling_policy import V2HPAScalingPolicy
from kubernetes.client.models.v2_hpa_scaling_rules import V2HPAScalingRules
from kubernetes.client.models.v2_horizontal_pod_autoscaler import V2HorizontalPodAutoscaler
from kubernetes.client.models.v2_horizontal_pod_autoscaler_behavior import V2HorizontalPodAutoscalerBehavior
from kubernetes.client.models.v2_horizontal_pod_autoscaler_condition import V2HorizontalPodAutoscalerCondition
from kubernetes.client.models.v2_horizontal_pod_autoscaler_list import V2HorizontalPodAutoscalerList
from kubernetes.client.models.v2_horizontal_pod_autoscaler_spec import V2HorizontalPodAutoscalerSpec
from kubernetes.client.models.v2_horizontal_pod_autoscaler_status import V2HorizontalPodAutoscalerStatus
from kubernetes.client.models.v2_metric_identifier import V2MetricIdentifier
from kubernetes.client.models.v2_metric_spec import V2MetricSpec
from kubernetes.client.models.v2_metric_status import V2MetricStatus
from kubernetes.client.models.v2_metric_target import V2MetricTarget
from kubernetes.client.models.v2_metric_value_status import V2MetricValueStatus
from kubernetes.client.models.v2_object_metric_source import V2ObjectMetricSource
from kubernetes.client.models.v2_object_metric_status import V2ObjectMetricStatus
from kubernetes.client.models.v2_pods_metric_source import V2PodsMetricSource
from kubernetes.client.models.v2_pods_metric_status import V2PodsMetricStatus
from kubernetes.client.models.v2_resource_metric_source import V2ResourceMetricSource
from kubernetes.client.models.v2_resource_metric_status import V2ResourceMetricStatus
from kubernetes.client.models.v2beta1_api_group_discovery import V2beta1APIGroupDiscovery
from kubernetes.client.models.v2beta1_api_group_discovery_list import V2beta1APIGroupDiscoveryList
from kubernetes.client.models.v2beta1_api_resource_discovery import V2beta1APIResourceDiscovery
from kubernetes.client.models.v2beta1_api_subresource_discovery import V2beta1APISubresourceDiscovery
from kubernetes.client.models.v2beta1_api_version_discovery import V2beta1APIVersionDiscovery
from kubernetes.client.models.version_info import VersionInfo




# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1FileKeySelector(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'key': 'str',
        'optional': 'bool',
        'path': 'str',
        'volume_name': 'str'
    }

    attribute_map = {
        'key': 'key',
        'optional': 'optional',
        'path': 'path',
        'volume_name': 'volumeName'
    }

    def __init__(self, key=None, optional=None, path=None, volume_name=None, local_vars_configuration=None):  # noqa: E501
        """V1FileKeySelector - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._key = None
        self._optional = None
        self._path = None
        self._volume_name = None
        self.discriminator = None

        self.key = key
        if optional is not None:
            self.optional = optional
        self.path = path
        self.volume_name = volume_name

    @property
    def key(self):
        """Gets the key of this V1FileKeySelector.  # noqa: E501

        The key within the env file. An invalid key will prevent the pod from starting. The keys defined within a source may consist of any printable ASCII characters except '='. During Alpha stage of the EnvFiles feature gate, the key size is limited to 128 characters.  # noqa: E501

        :return: The key of this V1FileKeySelector.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this V1FileKeySelector.

        The key within the env file. An invalid key will prevent the pod from starting. The keys defined within a source may consist of any printable ASCII characters except '='. During Alpha stage of the EnvFiles feature gate, the key size is limited to 128 characters.  # noqa: E501

        :param key: The key of this V1FileKeySelector.  # noqa: E501
        :type key: str
        """
        if self.local_vars_configuration.client_side_validation and key is None:  # noqa: E501
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    @property
    def optional(self):
        """Gets the optional of this V1FileKeySelector.  # noqa: E501

        Specify whether the file or its key must be defined. If the file or key does not exist, then the env var is not published. If optional is set to true and the specified key does not exist, the environment variable will not be set in the Pod's containers.  If optional is set to false and the specified key does not exist, an error will be returned during Pod creation.  # noqa: E501

        :return: The optional of this V1FileKeySelector.  # noqa: E501
        :rtype: bool
        """
        return self._optional

    @optional.setter
    def optional(self, optional):
        """Sets the optional of this V1FileKeySelector.

        Specify whether the file or its key must be defined. If the file or key does not exist, then the env var is not published. If optional is set to true and the specified key does not exist, the environment variable will not be set in the Pod's containers.  If optional is set to false and the specified key does not exist, an error will be returned during Pod creation.  # noqa: E501

        :param optional: The optional of this V1FileKeySelector.  # noqa: E501
        :type optional: bool
        """

        self._optional = optional

    @property
    def path(self):
        """Gets the path of this V1FileKeySelector.  # noqa: E501

        The path within the volume from which to select the file. Must be relative and may not contain the '..' path or start with '..'.  # noqa: E501

        :return: The path of this V1FileKeySelector.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this V1FileKeySelector.

        The path within the volume from which to select the file. Must be relative and may not contain the '..' path or start with '..'.  # noqa: E501

        :param path: The path of this V1FileKeySelector.  # noqa: E501
        :type path: str
        """
        if self.local_vars_configuration.client_side_validation and path is None:  # noqa: E501
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def volume_name(self):
        """Gets the volume_name of this V1FileKeySelector.  # noqa: E501

        The name of the volume mount containing the env file.  # noqa: E501

        :return: The volume_name of this V1FileKeySelector.  # noqa: E501
        :rtype: str
        """
        return self._volume_name

    @volume_name.setter
    def volume_name(self, volume_name):
        """Sets the volume_name of this V1FileKeySelector.

        The name of the volume mount containing the env file.  # noqa: E501

        :param volume_name: The volume_name of this V1FileKeySelector.  # noqa: E501
        :type volume_name: str
        """
        if self.local_vars_configuration.client_side_validation and volume_name is None:  # noqa: E501
            raise ValueError("Invalid value for `volume_name`, must not be `None`")  # noqa: E501

        self._volume_name = volume_name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1FileKeySelector):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1FileKeySelector):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1beta1ParamRef(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'namespace': 'str',
        'parameter_not_found_action': 'str',
        'selector': 'V1LabelSelector'
    }

    attribute_map = {
        'name': 'name',
        'namespace': 'namespace',
        'parameter_not_found_action': 'parameterNotFoundAction',
        'selector': 'selector'
    }

    def __init__(self, name=None, namespace=None, parameter_not_found_action=None, selector=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1ParamRef - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._namespace = None
        self._parameter_not_found_action = None
        self._selector = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if namespace is not None:
            self.namespace = namespace
        if parameter_not_found_action is not None:
            self.parameter_not_found_action = parameter_not_found_action
        if selector is not None:
            self.selector = selector

    @property
    def name(self):
        """Gets the name of this V1beta1ParamRef.  # noqa: E501

        name is the name of the resource being referenced.  One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.  A single parameter used for all admission requests can be configured by setting the `name` field, leaving `selector` blank, and setting namespace if `paramKind` is namespace-scoped.  # noqa: E501

        :return: The name of this V1beta1ParamRef.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta1ParamRef.

        name is the name of the resource being referenced.  One of `name` or `selector` must be set, but `name` and `selector` are mutually exclusive properties. If one is set, the other must be unset.  A single parameter used for all admission requests can be configured by setting the `name` field, leaving `selector` blank, and setting namespace if `paramKind` is namespace-scoped.  # noqa: E501

        :param name: The name of this V1beta1ParamRef.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def namespace(self):
        """Gets the namespace of this V1beta1ParamRef.  # noqa: E501

        namespace is the namespace of the referenced resource. Allows limiting the search for params to a specific namespace. Applies to both `name` and `selector` fields.  A per-namespace parameter may be used by specifying a namespace-scoped `paramKind` in the policy and leaving this field empty.  - If `paramKind` is cluster-scoped, this field MUST be unset. Setting this field results in a configuration error.  - If `paramKind` is namespace-scoped, the namespace of the object being evaluated for admission will be used when this field is left unset. Take care that if this is left empty the binding must not match any cluster-scoped resources, which will result in an error.  # noqa: E501

        :return: The namespace of this V1beta1ParamRef.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this V1beta1ParamRef.

        namespace is the namespace of the referenced resource. Allows limiting the search for params to a specific namespace. Applies to both `name` and `selector` fields.  A per-namespace parameter may be used by specifying a namespace-scoped `paramKind` in the policy and leaving this field empty.  - If `paramKind` is cluster-scoped, this field MUST be unset. Setting this field results in a configuration error.  - If `paramKind` is namespace-scoped, the namespace of the object being evaluated for admission will be used when this field is left unset. Take care that if this is left empty the binding must not match any cluster-scoped resources, which will result in an error.  # noqa: E501

        :param namespace: The namespace of this V1beta1ParamRef.  # noqa: E501
        :type namespace: str
        """

        self._namespace = namespace

    @property
    def parameter_not_found_action(self):
        """Gets the parameter_not_found_action of this V1beta1ParamRef.  # noqa: E501

        parameterNotFoundAction controls the behavior of the binding when the resource exists, and name or selector is valid, but there are no parameters matched by the binding. If the value is set to `Allow`, then no matched parameters will be treated as successful validation by the binding. If set to `Deny`, then no matched parameters will be subject to the `failurePolicy` of the policy.  Allowed values are `Allow` or `Deny`  Required  # noqa: E501

        :return: The parameter_not_found_action of this V1beta1ParamRef.  # noqa: E501
        :rtype: str
        """
        return self._parameter_not_found_action

    @parameter_not_found_action.setter
    def parameter_not_found_action(self, parameter_not_found_action):
        """Sets the parameter_not_found_action of this V1beta1ParamRef.

        parameterNotFoundAction controls the behavior of the binding when the resource exists, and name or selector is valid, but there are no parameters matched by the binding. If the value is set to `Allow`, then no matched parameters will be treated as successful validation by the binding. If set to `Deny`, then no matched parameters will be subject to the `failurePolicy` of the policy.  Allowed values are `Allow` or `Deny`  Required  # noqa: E501

        :param parameter_not_found_action: The parameter_not_found_action of this V1beta1ParamRef.  # noqa: E501
        :type parameter_not_found_action: str
        """

        self._parameter_not_found_action = parameter_not_found_action

    @property
    def selector(self):
        """Gets the selector of this V1beta1ParamRef.  # noqa: E501


        :return: The selector of this V1beta1ParamRef.  # noqa: E501
        :rtype: V1LabelSelector
        """
        return self._selector

    @selector.setter
    def selector(self, selector):
        """Sets the selector of this V1beta1ParamRef.


        :param selector: The selector of this V1beta1ParamRef.  # noqa: E501
        :type selector: V1LabelSelector
        """

        self._selector = selector

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1ParamRef):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1ParamRef):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1beta2DeviceRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'exactly': 'V1beta2ExactDeviceRequest',
        'first_available': 'list[V1beta2DeviceSubRequest]',
        'name': 'str'
    }

    attribute_map = {
        'exactly': 'exactly',
        'first_available': 'firstAvailable',
        'name': 'name'
    }

    def __init__(self, exactly=None, first_available=None, name=None, local_vars_configuration=None):  # noqa: E501
        """V1beta2DeviceRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._exactly = None
        self._first_available = None
        self._name = None
        self.discriminator = None

        if exactly is not None:
            self.exactly = exactly
        if first_available is not None:
            self.first_available = first_available
        self.name = name

    @property
    def exactly(self):
        """Gets the exactly of this V1beta2DeviceRequest.  # noqa: E501


        :return: The exactly of this V1beta2DeviceRequest.  # noqa: E501
        :rtype: V1beta2ExactDeviceRequest
        """
        return self._exactly

    @exactly.setter
    def exactly(self, exactly):
        """Sets the exactly of this V1beta2DeviceRequest.


        :param exactly: The exactly of this V1beta2DeviceRequest.  # noqa: E501
        :type exactly: V1beta2ExactDeviceRequest
        """

        self._exactly = exactly

    @property
    def first_available(self):
        """Gets the first_available of this V1beta2DeviceRequest.  # noqa: E501

        FirstAvailable contains subrequests, of which exactly one will be selected by the scheduler. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one can not be used.  DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.  # noqa: E501

        :return: The first_available of this V1beta2DeviceRequest.  # noqa: E501
        :rtype: list[V1beta2DeviceSubRequest]
        """
        return self._first_available

    @first_available.setter
    def first_available(self, first_available):
        """Sets the first_available of this V1beta2DeviceRequest.

        FirstAvailable contains subrequests, of which exactly one will be selected by the scheduler. It tries to satisfy them in the order in which they are listed here. So if there are two entries in the list, the scheduler will only check the second one if it determines that the first one can not be used.  DRA does not yet implement scoring, so the scheduler will select the first set of devices that satisfies all the requests in the claim. And if the requirements can be satisfied on more than one node, other scheduling features will determine which node is chosen. This means that the set of devices allocated to a claim might not be the optimal set available to the cluster. Scoring will be implemented later.  # noqa: E501

        :param first_available: The first_available of this V1beta2DeviceRequest.  # noqa: E501
        :type first_available: list[V1beta2DeviceSubRequest]
        """

        self._first_available = first_available

    @property
    def name(self):
        """Gets the name of this V1beta2DeviceRequest.  # noqa: E501

        Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.  References using the name in the DeviceRequest will uniquely identify a request when the Exactly field is set. When the FirstAvailable field is set, a reference to the name of the DeviceRequest will match whatever subrequest is chosen by the scheduler.  Must be a DNS label.  # noqa: E501

        :return: The name of this V1beta2DeviceRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta2DeviceRequest.

        Name can be used to reference this request in a pod.spec.containers[].resources.claims entry and in a constraint of the claim.  References using the name in the DeviceRequest will uniquely identify a request when the Exactly field is set. When the FirstAvailable field is set, a reference to the name of the DeviceRequest will match whatever subrequest is chosen by the scheduler.  Must be a DNS label.  # noqa: E501

        :param name: The name of this V1beta2DeviceRequest.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta2DeviceRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta2DeviceRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1EmptyDirVolumeSource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'medium': 'str',
        'size_limit': 'str'
    }

    attribute_map = {
        'medium': 'medium',
        'size_limit': 'sizeLimit'
    }

    def __init__(self, medium=None, size_limit=None, local_vars_configuration=None):  # noqa: E501
        """V1EmptyDirVolumeSource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._medium = None
        self._size_limit = None
        self.discriminator = None

        if medium is not None:
            self.medium = medium
        if size_limit is not None:
            self.size_limit = size_limit

    @property
    def medium(self):
        """Gets the medium of this V1EmptyDirVolumeSource.  # noqa: E501

        medium represents what type of storage medium should back this directory. The default is \"\" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir  # noqa: E501

        :return: The medium of this V1EmptyDirVolumeSource.  # noqa: E501
        :rtype: str
        """
        return self._medium

    @medium.setter
    def medium(self, medium):
        """Sets the medium of this V1EmptyDirVolumeSource.

        medium represents what type of storage medium should back this directory. The default is \"\" which means to use the node's default medium. Must be an empty string (default) or Memory. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir  # noqa: E501

        :param medium: The medium of this V1EmptyDirVolumeSource.  # noqa: E501
        :type medium: str
        """

        self._medium = medium

    @property
    def size_limit(self):
        """Gets the size_limit of this V1EmptyDirVolumeSource.  # noqa: E501

        sizeLimit is the total amount of local storage required for this EmptyDir volume. The size limit is also applicable for memory medium. The maximum usage on memory medium EmptyDir would be the minimum value between the SizeLimit specified here and the sum of memory limits of all containers in a pod. The default is nil which means that the limit is undefined. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir  # noqa: E501

        :return: The size_limit of this V1EmptyDirVolumeSource.  # noqa: E501
        :rtype: str
        """
        return self._size_limit

    @size_limit.setter
    def size_limit(self, size_limit):
        """Sets the size_limit of this V1EmptyDirVolumeSource.

        sizeLimit is the total amount of local storage required for this EmptyDir volume. The size limit is also applicable for memory medium. The maximum usage on memory medium EmptyDir would be the minimum value between the SizeLimit specified here and the sum of memory limits of all containers in a pod. The default is nil which means that the limit is undefined. More info: https://kubernetes.io/docs/concepts/storage/volumes#emptydir  # noqa: E501

        :param size_limit: The size_limit of this V1EmptyDirVolumeSource.  # noqa: E501
        :type size_limit: str
        """

        self._size_limit = size_limit

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1EmptyDirVolumeSource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1EmptyDirVolumeSource):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1alpha2PodGroupStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'conditions': 'list[V1Condition]',
        'resource_claim_statuses': 'list[V1alpha2PodGroupResourceClaimStatus]'
    }

    attribute_map = {
        'conditions': 'conditions',
        'resource_claim_statuses': 'resourceClaimStatuses'
    }

    def __init__(self, conditions=None, resource_claim_statuses=None, local_vars_configuration=None):  # noqa: E501
        """V1alpha2PodGroupStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._conditions = None
        self._resource_claim_statuses = None
        self.discriminator = None

        if conditions is not None:
            self.conditions = conditions
        if resource_claim_statuses is not None:
            self.resource_claim_statuses = resource_claim_statuses

    @property
    def conditions(self):
        """Gets the conditions of this V1alpha2PodGroupStatus.  # noqa: E501

        Conditions represent the latest observations of the PodGroup's state.  Known condition types: - \"PodGroupScheduled\": Indicates whether the scheduling requirement has been satisfied. - \"DisruptionTarget\": Indicates whether the PodGroup is about to be terminated   due to disruption such as preemption.  Known reasons for the PodGroupScheduled condition: - \"Unschedulable\": The PodGroup cannot be scheduled due to resource constraints,   affinity/anti-affinity rules, or insufficient capacity for the gang. - \"SchedulerError\": The PodGroup cannot be scheduled due to some internal error   that happened during scheduling, for example due to nodeAffinity parsing errors.  Known reasons for the DisruptionTarget condition: - \"PreemptionByScheduler\": The PodGroup was preempted by the scheduler to make room for   higher-priority PodGroups or Pods.  # noqa: E501

        :return: The conditions of this V1alpha2PodGroupStatus.  # noqa: E501
        :rtype: list[V1Condition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1alpha2PodGroupStatus.

        Conditions represent the latest observations of the PodGroup's state.  Known condition types: - \"PodGroupScheduled\": Indicates whether the scheduling requirement has been satisfied. - \"DisruptionTarget\": Indicates whether the PodGroup is about to be terminated   due to disruption such as preemption.  Known reasons for the PodGroupScheduled condition: - \"Unschedulable\": The PodGroup cannot be scheduled due to resource constraints,   affinity/anti-affinity rules, or insufficient capacity for the gang. - \"SchedulerError\": The PodGroup cannot be scheduled due to some internal error   that happened during scheduling, for example due to nodeAffinity parsing errors.  Known reasons for the DisruptionTarget condition: - \"PreemptionByScheduler\": The PodGroup was preempted by the scheduler to make room for   higher-priority PodGroups or Pods.  # noqa: E501

        :param conditions: The conditions of this V1alpha2PodGroupStatus.  # noqa: E501
        :type conditions: list[V1Condition]
        """

        self._conditions = conditions

    @property
    def resource_claim_statuses(self):
        """Gets the resource_claim_statuses of this V1alpha2PodGroupStatus.  # noqa: E501

        Status of resource claims.  # noqa: E501

        :return: The resource_claim_statuses of this V1alpha2PodGroupStatus.  # noqa: E501
        :rtype: list[V1alpha2PodGroupResourceClaimStatus]
        """
        return self._resource_claim_statuses

    @resource_claim_statuses.setter
    def resource_claim_statuses(self, resource_claim_statuses):
        """Sets the resource_claim_statuses of this V1alpha2PodGroupStatus.

        Status of resource claims.  # noqa: E501

        :param resource_claim_statuses: The resource_claim_statuses of this V1alpha2PodGroupStatus.  # noqa: E501
        :type resource_claim_statuses: list[V1alpha2PodGroupResourceClaimStatus]
        """

        self._resource_claim_statuses = resource_claim_statuses

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1alpha2PodGroupStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1alpha2PodGroupStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1beta2Device(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'all_nodes': 'bool',
        'allow_multiple_allocations': 'bool',
        'attributes': 'dict[str, V1beta2DeviceAttribute]',
        'binding_conditions': 'list[str]',
        'binding_failure_conditions': 'list[str]',
        'binds_to_node': 'bool',
        'capacity': 'dict[str, V1beta2DeviceCapacity]',
        'consumes_counters': 'list[V1beta2DeviceCounterConsumption]',
        'name': 'str',
        'node_allocatable_resource_mappings': 'dict[str, V1beta2NodeAllocatableResourceMapping]',
        'node_name': 'str',
        'node_selector': 'V1NodeSelector',
        'taints': 'list[V1beta2DeviceTaint]'
    }

    attribute_map = {
        'all_nodes': 'allNodes',
        'allow_multiple_allocations': 'allowMultipleAllocations',
        'attributes': 'attributes',
        'binding_conditions': 'bindingConditions',
        'binding_failure_conditions': 'bindingFailureConditions',
        'binds_to_node': 'bindsToNode',
        'capacity': 'capacity',
        'consumes_counters': 'consumesCounters',
        'name': 'name',
        'node_allocatable_resource_mappings': 'nodeAllocatableResourceMappings',
        'node_name': 'nodeName',
        'node_selector': 'nodeSelector',
        'taints': 'taints'
    }

    def __init__(self, all_nodes=None, allow_multiple_allocations=None, attributes=None, binding_conditions=None, binding_failure_conditions=None, binds_to_node=None, capacity=None, consumes_counters=None, name=None, node_allocatable_resource_mappings=None, node_name=None, node_selector=None, taints=None, local_vars_configuration=None):  # noqa: E501
        """V1beta2Device - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._all_nodes = None
        self._allow_multiple_allocations = None
        self._attributes = None
        self._binding_conditions = None
        self._binding_failure_conditions = None
        self._binds_to_node = None
        self._capacity = None
        self._consumes_counters = None
        self._name = None
        self._node_allocatable_resource_mappings = None
        self._node_name = None
        self._node_selector = None
        self._taints = None
        self.discriminator = None

        if all_nodes is not None:
            self.all_nodes = all_nodes
        if allow_multiple_allocations is not None:
            self.allow_multiple_allocations = allow_multiple_allocations
        if attributes is not None:
            self.attributes = attributes
        if binding_conditions is not None:
            self.binding_conditions = binding_conditions
        if binding_failure_conditions is not None:
            self.binding_failure_conditions = binding_failure_conditions
        if binds_to_node is not None:
            self.binds_to_node = binds_to_node
        if capacity is not None:
            self.capacity = capacity
        if consumes_counters is not None:
            self.consumes_counters = consumes_counters
        self.name = name
        if node_allocatable_resource_mappings is not None:
            self.node_allocatable_resource_mappings = node_allocatable_resource_mappings
        if node_name is not None:
            self.node_name = node_name
        if node_selector is not None:
            self.node_selector = node_selector
        if taints is not None:
            self.taints = taints

    @property
    def all_nodes(self):
        """Gets the all_nodes of this V1beta2Device.  # noqa: E501

        AllNodes indicates that all nodes have access to the device.  Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.  # noqa: E501

        :return: The all_nodes of this V1beta2Device.  # noqa: E501
        :rtype: bool
        """
        return self._all_nodes

    @all_nodes.setter
    def all_nodes(self, all_nodes):
        """Sets the all_nodes of this V1beta2Device.

        AllNodes indicates that all nodes have access to the device.  Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.  # noqa: E501

        :param all_nodes: The all_nodes of this V1beta2Device.  # noqa: E501
        :type all_nodes: bool
        """

        self._all_nodes = all_nodes

    @property
    def allow_multiple_allocations(self):
        """Gets the allow_multiple_allocations of this V1beta2Device.  # noqa: E501

        AllowMultipleAllocations marks whether the device is allowed to be allocated to multiple DeviceRequests.  If AllowMultipleAllocations is set to true, the device can be allocated more than once, and all of its capacity is consumable, regardless of whether the requestPolicy is defined or not.  # noqa: E501

        :return: The allow_multiple_allocations of this V1beta2Device.  # noqa: E501
        :rtype: bool
        """
        return self._allow_multiple_allocations

    @allow_multiple_allocations.setter
    def allow_multiple_allocations(self, allow_multiple_allocations):
        """Sets the allow_multiple_allocations of this V1beta2Device.

        AllowMultipleAllocations marks whether the device is allowed to be allocated to multiple DeviceRequests.  If AllowMultipleAllocations is set to true, the device can be allocated more than once, and all of its capacity is consumable, regardless of whether the requestPolicy is defined or not.  # noqa: E501

        :param allow_multiple_allocations: The allow_multiple_allocations of this V1beta2Device.  # noqa: E501
        :type allow_multiple_allocations: bool
        """

        self._allow_multiple_allocations = allow_multiple_allocations

    @property
    def attributes(self):
        """Gets the attributes of this V1beta2Device.  # noqa: E501

        Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.  The maximum number of attributes and capacities combined is 32.  # noqa: E501

        :return: The attributes of this V1beta2Device.  # noqa: E501
        :rtype: dict[str, V1beta2DeviceAttribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """Sets the attributes of this V1beta2Device.

        Attributes defines the set of attributes for this device. The name of each attribute must be unique in that set.  The maximum number of attributes and capacities combined is 32.  # noqa: E501

        :param attributes: The attributes of this V1beta2Device.  # noqa: E501
        :type attributes: dict[str, V1beta2DeviceAttribute]
        """

        self._attributes = attributes

    @property
    def binding_conditions(self):
        """Gets the binding_conditions of this V1beta2Device.  # noqa: E501

        BindingConditions defines the conditions for proceeding with binding. All of these conditions must be set in the per-device status conditions with a value of True to proceed with binding the pod to the node while scheduling the pod.  The maximum number of binding conditions is 4.  The conditions must be a valid condition type string.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :return: The binding_conditions of this V1beta2Device.  # noqa: E501
        :rtype: list[str]
        """
        return self._binding_conditions

    @binding_conditions.setter
    def binding_conditions(self, binding_conditions):
        """Sets the binding_conditions of this V1beta2Device.

        BindingConditions defines the conditions for proceeding with binding. All of these conditions must be set in the per-device status conditions with a value of True to proceed with binding the pod to the node while scheduling the pod.  The maximum number of binding conditions is 4.  The conditions must be a valid condition type string.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :param binding_conditions: The binding_conditions of this V1beta2Device.  # noqa: E501
        :type binding_conditions: list[str]
        """

        self._binding_conditions = binding_conditions

    @property
    def binding_failure_conditions(self):
        """Gets the binding_failure_conditions of this V1beta2Device.  # noqa: E501

        BindingFailureConditions defines the conditions for binding failure. They may be set in the per-device status conditions. If any is set to \"True\", a binding failure occurred.  The maximum number of binding failure conditions is 4.  The conditions must be a valid condition type string.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :return: The binding_failure_conditions of this V1beta2Device.  # noqa: E501
        :rtype: list[str]
        """
        return self._binding_failure_conditions

    @binding_failure_conditions.setter
    def binding_failure_conditions(self, binding_failure_conditions):
        """Sets the binding_failure_conditions of this V1beta2Device.

        BindingFailureConditions defines the conditions for binding failure. They may be set in the per-device status conditions. If any is set to \"True\", a binding failure occurred.  The maximum number of binding failure conditions is 4.  The conditions must be a valid condition type string.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :param binding_failure_conditions: The binding_failure_conditions of this V1beta2Device.  # noqa: E501
        :type binding_failure_conditions: list[str]
        """

        self._binding_failure_conditions = binding_failure_conditions

    @property
    def binds_to_node(self):
        """Gets the binds_to_node of this V1beta2Device.  # noqa: E501

        BindsToNode indicates if the usage of an allocation involving this device has to be limited to exactly the node that was chosen when allocating the claim. If set to true, the scheduler will set the ResourceClaim.Status.Allocation.NodeSelector to match the node where the allocation was made.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :return: The binds_to_node of this V1beta2Device.  # noqa: E501
        :rtype: bool
        """
        return self._binds_to_node

    @binds_to_node.setter
    def binds_to_node(self, binds_to_node):
        """Sets the binds_to_node of this V1beta2Device.

        BindsToNode indicates if the usage of an allocation involving this device has to be limited to exactly the node that was chosen when allocating the claim. If set to true, the scheduler will set the ResourceClaim.Status.Allocation.NodeSelector to match the node where the allocation was made.  This is a beta field and requires enabling the DRADeviceBindingConditions and DRAResourceClaimDeviceStatus feature gates.  # noqa: E501

        :param binds_to_node: The binds_to_node of this V1beta2Device.  # noqa: E501
        :type binds_to_node: bool
        """

        self._binds_to_node = binds_to_node

    @property
    def capacity(self):
        """Gets the capacity of this V1beta2Device.  # noqa: E501

        Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.  The maximum number of attributes and capacities combined is 32.  # noqa: E501

        :return: The capacity of this V1beta2Device.  # noqa: E501
        :rtype: dict[str, V1beta2DeviceCapacity]
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this V1beta2Device.

        Capacity defines the set of capacities for this device. The name of each capacity must be unique in that set.  The maximum number of attributes and capacities combined is 32.  # noqa: E501

        :param capacity: The capacity of this V1beta2Device.  # noqa: E501
        :type capacity: dict[str, V1beta2DeviceCapacity]
        """

        self._capacity = capacity

    @property
    def consumes_counters(self):
        """Gets the consumes_counters of this V1beta2Device.  # noqa: E501

        ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.  There can only be a single entry per counterSet.  The maximum number of device counter consumptions per device is 2.  # noqa: E501

        :return: The consumes_counters of this V1beta2Device.  # noqa: E501
        :rtype: list[V1beta2DeviceCounterConsumption]
        """
        return self._consumes_counters

    @consumes_counters.setter
    def consumes_counters(self, consumes_counters):
        """Sets the consumes_counters of this V1beta2Device.

        ConsumesCounters defines a list of references to sharedCounters and the set of counters that the device will consume from those counter sets.  There can only be a single entry per counterSet.  The maximum number of device counter consumptions per device is 2.  # noqa: E501

        :param consumes_counters: The consumes_counters of this V1beta2Device.  # noqa: E501
        :type consumes_counters: list[V1beta2DeviceCounterConsumption]
        """

        self._consumes_counters = consumes_counters

    @property
    def name(self):
        """Gets the name of this V1beta2Device.  # noqa: E501

        Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.  # noqa: E501

        :return: The name of this V1beta2Device.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta2Device.

        Name is unique identifier among all devices managed by the driver in the pool. It must be a DNS label.  # noqa: E501

        :param name: The name of this V1beta2Device.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def node_allocatable_resource_mappings(self):
        """Gets the node_allocatable_resource_mappings of this V1beta2Device.  # noqa: E501

        NodeAllocatableResourceMappings defines the mapping of node resources that are managed by the DRA driver exposing this device. This includes resources currently reported in v1.Node `status.allocatable` that are not extended resources (see https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/#extended-resources). Examples include \"cpu\", \"memory\", \"ephemeral-storage\", and hugepages. In addition to standard requests made through the Pod `spec`, these resources can also be requested through claims and allocated by the DRA driver. For example, a CPU DRA driver might allocate exclusive CPUs or auxiliary node memory dependencies of an accelerator device. The keys of this map are the node-allocatable resource names (e.g., \"cpu\", \"memory\"). Extended resource names are not permitted as keys.  # noqa: E501

        :return: The node_allocatable_resource_mappings of this V1beta2Device.  # noqa: E501
        :rtype: dict[str, V1beta2NodeAllocatableResourceMapping]
        """
        return self._node_allocatable_resource_mappings

    @node_allocatable_resource_mappings.setter
    def node_allocatable_resource_mappings(self, node_allocatable_resource_mappings):
        """Sets the node_allocatable_resource_mappings of this V1beta2Device.

        NodeAllocatableResourceMappings defines the mapping of node resources that are managed by the DRA driver exposing this device. This includes resources currently reported in v1.Node `status.allocatable` that are not extended resources (see https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/#extended-resources). Examples include \"cpu\", \"memory\", \"ephemeral-storage\", and hugepages. In addition to standard requests made through the Pod `spec`, these resources can also be requested through claims and allocated by the DRA driver. For example, a CPU DRA driver might allocate exclusive CPUs or auxiliary node memory dependencies of an accelerator device. The keys of this map are the node-allocatable resource names (e.g., \"cpu\", \"memory\"). Extended resource names are not permitted as keys.  # noqa: E501

        :param node_allocatable_resource_mappings: The node_allocatable_resource_mappings of this V1beta2Device.  # noqa: E501
        :type node_allocatable_resource_mappings: dict[str, V1beta2NodeAllocatableResourceMapping]
        """

        self._node_allocatable_resource_mappings = node_allocatable_resource_mappings

    @property
    def node_name(self):
        """Gets the node_name of this V1beta2Device.  # noqa: E501

        NodeName identifies the node where the device is available.  Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.  # noqa: E501

        :return: The node_name of this V1beta2Device.  # noqa: E501
        :rtype: str
        """
        return self._node_name

    @node_name.setter
    def node_name(self, node_name):
        """Sets the node_name of this V1beta2Device.

        NodeName identifies the node where the device is available.  Must only be set if Spec.PerDeviceNodeSelection is set to true. At most one of NodeName, NodeSelector and AllNodes can be set.  # noqa: E501

        :param node_name: The node_name of this V1beta2Device.  # noqa: E501
        :type node_name: str
        """

        self._node_name = node_name

    @property
    def node_selector(self):
        """Gets the node_selector of this V1beta2Device.  # noqa: E501


        :return: The node_selector of this V1beta2Device.  # noqa: E501
        :rtype: V1NodeSelector
        """
        return self._node_selector

    @node_selector.setter
    def node_selector(self, node_selector):
        """Sets the node_selector of this V1beta2Device.


        :param node_selector: The node_selector of this V1beta2Device.  # noqa: E501
        :type node_selector: V1NodeSelector
        """

        self._node_selector = node_selector

    @property
    def taints(self):
        """Gets the taints of this V1beta2Device.  # noqa: E501

        If specified, these are the driver-defined taints.  The maximum number of taints is 16. If taints are set for any device in a ResourceSlice, then the maximum number of allowed devices per ResourceSlice is 64 instead of 128.  This is a beta field and requires enabling the DRADeviceTaints feature gate.  # noqa: E501

        :return: The taints of this V1beta2Device.  # noqa: E501
        :rtype: list[V1beta2DeviceTaint]
        """
        return self._taints

    @taints.setter
    def taints(self, taints):
        """Sets the taints of this V1beta2Device.

        If specified, these are the driver-defined taints.  The maximum number of taints is 16. If taints are set for any device in a ResourceSlice, then the maximum number of allowed devices per ResourceSlice is 64 instead of 128.  This is a beta field and requires enabling the DRADeviceTaints feature gate.  # noqa: E501

        :param taints: The taints of this V1beta2Device.  # noqa: E501
        :type taints: list[V1beta2DeviceTaint]
        """

        self._taints = taints

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta2Device):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta2Device):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V1LoadBalancerIngress(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'hostname': 'str',
        'ip': 'str',
        'ip_mode': 'str',
        'ports': 'list[V1PortStatus]'
    }

    attribute_map = {
        'hostname': 'hostname',
        'ip': 'ip',
        'ip_mode': 'ipMode',
        'ports': 'ports'
    }

    def __init__(self, hostname=None, ip=None, ip_mode=None, ports=None, local_vars_configuration=None):  # noqa: E501
        """V1LoadBalancerIngress - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._hostname = None
        self._ip = None
        self._ip_mode = None
        self._ports = None
        self.discriminator = None

        if hostname is not None:
            self.hostname = hostname
        if ip is not None:
            self.ip = ip
        if ip_mode is not None:
            self.ip_mode = ip_mode
        if ports is not None:
            self.ports = ports

    @property
    def hostname(self):
        """Gets the hostname of this V1LoadBalancerIngress.  # noqa: E501

        Hostname is set for load-balancer ingress points that are DNS based (typically AWS load-balancers)  # noqa: E501

        :return: The hostname of this V1LoadBalancerIngress.  # noqa: E501
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """Sets the hostname of this V1LoadBalancerIngress.

        Hostname is set for load-balancer ingress points that are DNS based (typically AWS load-balancers)  # noqa: E501

        :param hostname: The hostname of this V1LoadBalancerIngress.  # noqa: E501
        :type hostname: str
        """

        self._hostname = hostname

    @property
    def ip(self):
        """Gets the ip of this V1LoadBalancerIngress.  # noqa: E501

        IP is set for load-balancer ingress points that are IP based (typically GCE or OpenStack load-balancers)  # noqa: E501

        :return: The ip of this V1LoadBalancerIngress.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this V1LoadBalancerIngress.

        IP is set for load-balancer ingress points that are IP based (typically GCE or OpenStack load-balancers)  # noqa: E501

        :param ip: The ip of this V1LoadBalancerIngress.  # noqa: E501
        :type ip: str
        """

        self._ip = ip

    @property
    def ip_mode(self):
        """Gets the ip_mode of this V1LoadBalancerIngress.  # noqa: E501

        IPMode specifies how the load-balancer IP behaves, and may only be specified when the ip field is specified. Setting this to \"VIP\" indicates that traffic is delivered to the node with the destination set to the load-balancer's IP and port. Setting this to \"Proxy\" indicates that traffic is delivered to the node or pod with the destination set to the node's IP and node port or the pod's IP and port. Service implementations may use this information to adjust traffic routing.  # noqa: E501

        :return: The ip_mode of this V1LoadBalancerIngress.  # noqa: E501
        :rtype: str
        """
        return self._ip_mode

    @ip_mode.setter
    def ip_mode(self, ip_mode):
        """Sets the ip_mode of this V1LoadBalancerIngress.

        IPMode specifies how the load-balancer IP behaves, and may only be specified when the ip field is specified. Setting this to \"VIP\" indicates that traffic is delivered to the node with the destination set to the load-balancer's IP and port. Setting this to \"Proxy\" indicates that traffic is delivered to the node or pod with the destination set to the node's IP and node port or the pod's IP and port. Service implementations may use this information to adjust traffic routing.  # noqa: E501

        :param ip_mode: The ip_mode of this V1LoadBalancerIngress.  # noqa: E501
        :type ip_mode: str
        """

        self._ip_mode = ip_mode

    @property
    def ports(self):
        """Gets the ports of this V1LoadBalancerIngress.  # noqa: E501

        Ports is a list of records of service ports If used, every port defined in the service should have an entry in it  # noqa: E501

        :return: The ports of this V1LoadBalancerIngress.  # noqa: E501
        :rtype: list[V1PortStatus]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this V1LoadBalancerIngress.

        Ports is a list of records of service ports If used, every port defined in the service should have an entry in it  # noqa: E501

        :param ports: The ports of this V1LoadBalancerIngress.  # noqa: E501
        :type ports: list[V1PortStatus]
        """

        self._ports = ports

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LoadBalancerIngress):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1LoadBalancerIngress):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.36
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from kubernetes.client.configuration import Configuration


class V2APIResourceDiscovery(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'resource': 'str',
        'response_kind': 'IoK8sApimachineryPkgApisMetaV1GroupVersionKind',
        'scope': 'str',
        'singular_resource': 'str',
        'verbs': 'list[str]',
        'short_names': 'list[str]',
        'categories': 'list[str]',
        'subresources': 'list[V2APISubresourceDiscovery]'
    }

    attribute_map = {
        'resource': 'resource',
        'response_kind': 'responseKind',
        'scope': 'scope',
        'singular_resource': 'singularResource',
        'verbs': 'verbs',
        'short_names': 'shortNames',
        'categories': 'categories',
        'subresources': 'subresources'
    }

    def __init__(self, resource=None, response_kind=None, scope=None, singular_resource=None, verbs=None, short_names=None, categories=None, subresources=None, local_vars_configuration=None):  # noqa: E501
        """V2APIResourceDiscovery - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._resource = None
        self._response_kind = None
        self._scope = None
        self._singular_resource = None
        self._verbs = None
        self._short_names = None
        self._categories = None
        self._subresources = None
        self.discriminator = None

        self.resource = resource
        if response_kind is not None:
            self.response_kind = response_kind
        self.scope = scope
        self.singular_resource = singular_resource
        self.verbs = verbs
        if short_names is not None:
            self.short_names = short_names
        if categories is not None:
            self.categories = categories
        if subresources is not None:
            self.subresources = subresources

    @property
    def resource(self):
        """Gets the resource of this V2APIResourceDiscovery.  # noqa: E501

        resource is the plural name of the resource.  # noqa: E501

        :return: The resource of this V2APIResourceDiscovery.  # noqa: E501
        :rtype: str
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """Sets the resource of this V2APIResourceDiscovery.

        resource is the plural name of the resource.  # noqa: E501

        :param resource: The resource of this V2APIResourceDiscovery.  # noqa: E501
        :type resource: str
        """
        if self.local_vars_configuration.client_side_validation and resource is None:  # noqa: E501
            raise ValueError("Invalid value for `resource`, must not be `None`")  # noqa: E501

        self._resource = resource

    @property
    def response_kind(self):
        """Gets the response_kind of this V2APIResourceDiscovery.  # noqa: E501


        :return: The response_kind of this V2APIResourceDiscovery.  # noqa: E501
        :rtype: IoK8sApimachineryPkgApisMetaV1GroupVersionKind
        """
        return self._response_kind

    @response_kind.setter
    def response_kind(self, response_kind):
        """Sets the response_kind of this V2APIResourceDiscovery.


        :param response_kind: The response_kind of this V2APIResourceDiscovery.  # noqa: E501
        :type response_kind: IoK8sApimachineryPkgApisMetaV1GroupVersionKind
        """

        self._response_kind = response_kind

    @property
    def scope(self):
        """Gets the scope of this V2APIResourceDiscovery.  # noqa: E501

        scope indicates the scope of a resource, either Cluster or Namespaced  # noqa: E501

        :return: The scope of this V2APIResourceDiscovery.  # noqa: E501
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """Sets the scope of this V2APIResourceDiscovery.

        scope indicates the scope of a resource, either Cluster or Namespaced  # noqa: E501

        :param scope: The scope of this V2APIResourceDiscovery.  # noqa: E501
        :type scope: str
        """
        if self.local_vars_configuration.client_side_validation and scope is None:  # noqa: E501
            raise ValueError("Invalid value for `scope`, must not be `None`")  # noqa: E501

        self._scope = scope

    @property
    def singular_resource(self):
        """Gets the singular_resource of this V2APIResourceDiscovery.  # noqa: E501

        singularResource is the singular name of the resource.  # noqa: E501

        :return: The singular_resource of this V2APIResourceDiscovery.  # noqa: E501
        :rtype: str
        """
        return self._singular_resource

    @singular_resource.setter
    def singular_resource(self, singular_resource):
        """Sets the singular_resource of this V2APIResourceDiscovery.

        singularResource is the singular name of the resource.  # noqa: E501

        :param singular_resource: The singular_resource of this V2APIResourceDiscovery.  # noqa: E501
        :type singular_resource: str
        """
        if self.local_vars_configuration.client_side_validation and singular_resource is None:  # noqa: E501
            raise ValueError("Invalid value for `singular_resource`, must not be `None`")  # noqa: E501

        self._singular_resource = singular_resource

    @property
    def verbs(self):
        """Gets the verbs of this V2APIResourceDiscovery.  # noqa: E501

        verbs is a list of supported API operation types  # noqa: E501

        :return: The verbs of this V2APIResourceDiscovery.  # noqa: E501
        :rtype: list[str]
        """
        return self._verbs

    @verbs.setter
    def verbs(self, verbs):
        """Sets the verbs of this V2APIResourceDiscovery.

        verbs is a list of supported API operation types  # noqa: E501

        :param verbs: The verbs of this V2APIResourceDiscovery.  # noqa: E501
        :type verbs: list[str]
        """
        if self.local_vars_configuration.client_side_validation and verbs is None:  # noqa: E501
            raise ValueError("Invalid value for `verbs`, must not be `None`")  # noqa: E501

        self._verbs = verbs

    @property
    def short_names(self):
        """Gets the short_names of this V2APIResourceDiscovery.  # noqa: E501

        shortNames is a list of suggested short names of the resource.  # noqa: E501

        :return: The short_names of this V2APIResourceDiscovery.  # noqa: E501
        :rtype: list[str]
        """
        return self._short_names

    @short_names.setter
    def short_names(self, short_names):
        """Sets the short_names of this V2APIResourceDiscovery.

        shortNames is a list of suggested short names of the resource.  # noqa: E501

        :param short_names: The short_names of this V2APIResourceDiscovery.  # noqa: E501
        :type short_names: list[str]
        """

        self._short_names = short_names

    @property
    def categories(self):
        """Gets the categories of this V2APIResourceDiscovery.  # noqa: E501

        categories is a list of the grouped resources this resource belongs to.  # noqa: E501

        :return: The categories of this V2APIResourceDiscovery.  # noqa: E501
        :rtype: list[str]
        """
        return self._categories

    @categories.setter
    def categories(self, categories):
        """Sets the categories of this V2APIResourceDiscovery.

        categories is a list of the grouped resources this resource belongs to.  # noqa: E501

        :param categories: The categories of this V2APIResourceDiscovery.  # noqa: E501
        :type categories: list[str]
        """

        self._categories = categories

    @property
    def subresources(self):
        """Gets the subresources of this V2APIResourceDiscovery.  # noqa: E501


        :return: The subresources of this V2APIResourceDiscovery.  # noqa: E501
        :rtype: list[V2APISubresourceDiscovery]
        """
        return self._subresources

    @subresources.setter
    def subresources(self, subresources):
        """Sets the subresources of this V2APIResourceDiscovery.


        :param subresources: The subresources of this V2APIResourceDiscovery.  # noqa: E501
        :type subresources: list[V2APISubresourceDiscovery]
        """

        self._subresources = subresources

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V2APIResourceDiscovery):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V2APIResourceDiscovery):
            return True

        return self.to_dict() != other.to_dict()
